@@ -1,16 +1,11 @@
-# #
-# Copyright 2009-2014 Ghent University
-# Copyright 2009-2014 Stijn De Weirdt
-# Copyright 2010 Dries Verdegem
-# Copyright 2010-2014 Kenneth Hoste
-# Copyright 2011 Pieter De Baets
-# Copyright 2011-2014 Jens Timmerman
+##
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -26,15 +21,31 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
-# #
+##
+"""
+easybuild.easyblocks package declaration
+
+@author: Stijn De Weirdt (Ghent University)
+@author: Dries Verdegem (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+@author: Pieter De Baets (Ghent University)
+@author: Jens Timmerman (Ghent University)
+"""
 import os
+import pkg_resources
 from distutils.version import LooseVersion
 from pkgutil import extend_path
 
 # note: release candidates should be versioned as a pre-release, e.g. "1.1rc1"
 # 1.1-rc1 would indicate a post-release, i.e., and update of 1.1, so beware
-VERSION = LooseVersion("1.16.1")
-UNKNOWN = "UNKNOWN"
+#
+# important note: dev versions should follow the 'X.Y.Z.dev0' format
+# see https://www.python.org/dev/peps/pep-0440/#developmental-releases
+# recent setuptools versions will *TRANSFORM* something like 'X.Y.Zdev' into 'X.Y.Z.dev0', with a warning like
+#   UserWarning: Normalizing '2.4.0dev' to '2.4.0.dev0'
+# This causes problems further up the dependency chain...
+VERSION = LooseVersion('3.3.0')
+UNKNOWN = 'UNKNOWN'
 
 
 def get_git_revision():
@@ -60,13 +71,15 @@ git_rev = get_git_revision()
 if git_rev == UNKNOWN:
     VERBOSE_VERSION = VERSION
 else:
-    VERBOSE_VERSION = LooseVersion("%s-r%s" % (VERSION, get_git_revision()))
+    VERBOSE_VERSION = LooseVersion("%s-r%s" % (VERSION, git_rev))
 
-# Extend path so python finds our easyblocks in the subdirectories where they are located
+# extend path so python finds our easyblocks in the subdirectories where they are located
 subdirs = [chr(l) for l in range(ord('a'), ord('z') + 1)] + ['0']
-__path__.extend([os.path.join(__path__[0], subdir) for subdir in subdirs])
-# And let python know this is not the only place to look for them, so we can have multiple
-# easybuild/easyblock paths in your python search path, next to the official easyblocks distribution
-__path__ = extend_path(__path__, __name__)  # @ReservedAssignment
+for subdir in subdirs:
+    __path__ = extend_path(__path__, '%s.%s' % (__name__, subdir))
 
 del subdir, subdirs, l, git_rev
+
+# let python know this is not the only place to look for easyblocks, so we can have multiple
+# easybuild/easyblocks paths in the Python search path, next to the official easyblocks distribution
+pkg_resources.declare_namespace(__name__)
