@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -40,9 +40,10 @@ from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.framework.easyconfig import CUSTOM
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.modules import get_software_root
 from easybuild.tools.run import run_cmd
-from easybuild.tools.systemtools import get_cpu_speed
+from easybuild.tools.systemtools import AMD, INTEL, get_cpu_speed, get_cpu_vendor, get_shared_lib_ext
 
 
 class EB_ATLAS(ConfigureMake):
@@ -86,12 +87,15 @@ class EB_ATLAS(ConfigureMake):
                     sys.stdout.write(line)
             self.log.warning('CPU throttling check ignored: NOT recommended!')
 
-        # use cycle accurate timer for timings
-        # see http://math-atlas.sourceforge.net/atlas_install/node23.html
-        # this should work on Linux with both GCC and Intel compilers
-        cpu_freq = int(get_cpu_speed())
-        self.cfg.update('configopts', "-D c -DPentiumCPS=%s" % cpu_freq)
-
+        if get_cpu_vendor() in [AMD, INTEL]:
+            # use cycle accurate timer for timings
+            # see http://math-atlas.sourceforge.net/atlas_install/node23.html
+            # this should work on Linux with both GCC and Intel compilers
+            cpu_freq = int(get_cpu_speed())
+            self.cfg.update('configopts', "-D c -DPentiumCPS=%s" % cpu_freq)
+        else:
+            # use -DWALL for non-x86, see http://math-atlas.sourceforge.net/atlas_install/node25.html
+            self.cfg.update('configopts', "-D c -DWALL")
 
         # if LAPACK is found, instruct ATLAS to provide a full LAPACK library
         # ATLAS only provides a few LAPACK routines natively
@@ -103,8 +107,8 @@ class EB_ATLAS(ConfigureMake):
                 if lapack:
                     self.cfg.update('configopts', ' --with-netlib-lapack=%s/lib/liblapack.a' % lapack)
                 else:
-                    self.log.error("netlib's LAPACK library not available,"\
-                                   " required to build ATLAS with a full LAPACK library.")
+                    raise EasyBuildError("netlib's LAPACK library not available, required to build ATLAS "
+                                         "with a full LAPACK library.")
             else:
                 # pass LAPACK source tarball
                 lapack_src = None
@@ -114,7 +118,7 @@ class EB_ATLAS(ConfigureMake):
                 if lapack_src is not None:
                     self.cfg.update('configopts', ' --with-netlib-lapack-tarfile=%s' % lapack_src)
                 else:
-                    self.log.error("LAPACK source tarball not available, but required.")
+                    raise EasyBuildError("LAPACK source tarball not available, but required.")
 
         # enable building of shared libraries (requires -fPIC)
         if self.cfg['sharedlibs'] or self.toolchain.options['pic']:
@@ -127,7 +131,7 @@ class EB_ATLAS(ConfigureMake):
             os.makedirs(objdir)
             os.chdir(objdir)
         except OSError, err:
-            self.log.error("Failed to create obj directory to build in: %s" % err)
+            raise EasyBuildError("Failed to create obj directory to build in: %s", err)
 
         # specify compilers
         self.cfg.update('configopts', '-C ic %(cc)s -C if %(f77)s' % {
@@ -143,15 +147,15 @@ class EB_ATLAS(ConfigureMake):
         if exitcode != 0:
             throttling_regexp = re.compile("cpu throttling [a-zA-Z]* enabled", re.IGNORECASE)
             if throttling_regexp.search(out):
-                errormsg = """Configure failed, possible because CPU throttling is enabled; ATLAS doesn't like that.
-You can either disable CPU throttling, or set 'ignorethrottling' to True in the ATLAS .eb spec file.
-Also see http://math-atlas.sourceforge.net/errata.html#cputhrottle .
-Configure output:
-%s """ % out
+                errormsg = ' '.join([
+                    "Configure failed, possible because CPU throttling is enabled; ATLAS doesn't like that. ",
+                    "You can either disable CPU throttling, or set 'ignorethrottling' to True in the ATLAS .eb spec file.",
+                    "Also see http://math-atlas.sourceforge.net/errata.html#cputhrottle .",
+                    "Configure output: %s",
+                ]) % out
             else:
-                errormsg = """configure output: %s
-Configure failed, not sure why (see output above).""" % out
-            self.log.error(errormsg)
+                errormsg = "configure output: %s\nConfigure failed, not sure why (see output above)." % out
+            raise EasyBuildError(errormsg)
 
     def build_step(self, verbose=False):
 
@@ -167,7 +171,7 @@ Configure failed, not sure why (see output above).""" % out
             try:
                 os.chdir('lib')
             except OSError, err:
-                self.log.error("Failed to change to 'lib' directory for building the shared libs." % err)
+                raise EasyBuildError("Failed to change to 'lib' directory for building the shared libs.", err)
 
             self.log.debug("Building shared libraries")
             cmd = "make shared cshared ptshared cptshared"
@@ -176,7 +180,7 @@ Configure failed, not sure why (see output above).""" % out
             try:
                 os.chdir('..')
             except OSError, err:
-                self.log.error("Failed to get back to previous dir after building shared libs: %s " % err)
+                raise EasyBuildError("Failed to get back to previous dir after building shared libs: %s ", err)
 
     def install_step(self):
         """Install step
@@ -186,7 +190,7 @@ Configure failed, not sure why (see output above).""" % out
         """
         super(EB_ATLAS, self).install_step()
         if not self.cfg['full_lapack']:
-            for i in ['liblapack.a', 'liblapack.so']:
+            for i in ['liblapack.a', 'liblapack.%s' % get_shared_lib_ext()]:
                 lib = os.path.join(self.installdir, "lib", i[0])
                 if os.path.exists(lib):
                     os.rename(lib, os.path.join(self.installdir, "lib",
@@ -227,7 +231,8 @@ Configure failed, not sure why (see output above).""" % out
         static_libs = ["lib/lib%s.a" % x for x in libs]
 
         if self.cfg['sharedlibs']:
-            shared_libs = ["lib/lib%s.so" % x for x in libs]
+            shlib_ext = get_shared_lib_ext()
+            shared_libs = ["lib/lib%s.%s" % (x, shlib_ext) for x in libs]
         else:
             shared_libs = []
 
