@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -31,6 +31,11 @@ EasyBuild support for Boost, implemented as an easyblock
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
 @author: Ward Poelmans (Ghent University)
+@author: Petar Forai (IMP/IMBA)
+@author: Luca Marsella (CSCS)
+@author: Guilherme Peretti-Pezzi (CSCS)
+@author: Joachim Hein (Lund University)
+@author: Michele Dolfi (ETH Zurich)
 """
 from distutils.version import LooseVersion
 import fileinput
@@ -43,9 +48,11 @@ import sys
 import easybuild.tools.toolchain as toolchain
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM
+from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.filetools import write_file
 from easybuild.tools.modules import get_software_root
 from easybuild.tools.run import run_cmd
-from easybuild.tools.systemtools import get_glibc_version, UNKNOWN
+from easybuild.tools.systemtools import UNKNOWN, get_glibc_version, get_shared_lib_ext
 
 
 class EB_Boost(EasyBlock):
@@ -62,7 +69,9 @@ class EB_Boost(EasyBlock):
         """Add extra easyconfig parameters for Boost."""
         extra_vars = {
             'boost_mpi': [False, "Build mpi boost module", CUSTOM],
+            'boost_multi_thread': [False, "Build boost with multi-thread option", CUSTOM],
             'toolset': [None, "Toolset to use for Boost configuration ('--with-toolset for bootstrap.sh')", CUSTOM],
+            'mpi_launcher': [None, "Launcher to use when running MPI regression tests", CUSTOM],
         }
         return EasyBlock.extra_options(extra_vars)
 
@@ -70,10 +79,10 @@ class EB_Boost(EasyBlock):
         """Patch Boost source code before building."""
         super(EB_Boost, self).patch_step()
 
-        # TIME_UTC is also defined in recent glibc versions, so we need to rename it for old Boost versions (<= 1.47)
+        # TIME_UTC is also defined in recent glibc versions, so we need to rename it for old Boost versions (<= 1.49)
         glibc_version = get_glibc_version()
         old_glibc = glibc_version is not UNKNOWN and LooseVersion(glibc_version) > LooseVersion("2.15")
-        if old_glibc and LooseVersion(self.version) <= LooseVersion("1.47.0"):
+        if old_glibc and LooseVersion(self.version) <= LooseVersion("1.49.0"):
             self.log.info("Patching because the glibc version is too new")
             files_to_patch = ["boost/thread/xtime.hpp"] + glob.glob("libs/interprocess/test/*.hpp")
             files_to_patch += glob.glob("libs/spirit/classic/test/*.cpp") + glob.glob("libs/spirit/classic/test/*.inl")
@@ -83,14 +92,14 @@ class EB_Boost(EasyBlock):
                         line = re.sub(r"TIME_UTC", r"TIME_UTC_", line)
                         sys.stdout.write(line)
                 except IOError, err:
-                    self.log.error("Failed to patch %s: %s" % (patchfile, err))
+                    raise EasyBuildError("Failed to patch %s: %s", patchfile, err)
 
     def configure_step(self):
         """Configure Boost build using custom tools"""
 
         # mpi sanity check
         if self.cfg['boost_mpi'] and not self.toolchain.options.get('usempi', None):
-            self.log.error("When enabling building boost_mpi, also enable the 'usempi' toolchain option.")
+            raise EasyBuildError("When enabling building boost_mpi, also enable the 'usempi' toolchain option.")
 
         # create build directory (Boost doesn't like being built in source dir)
         try:
@@ -98,7 +107,7 @@ class EB_Boost(EasyBlock):
             os.mkdir(self.objdir)
             self.log.debug("Succesfully created directory %s" % self.objdir)
         except OSError, err:
-            self.log.error("Failed to create directory %s: %s" % (self.objdir, err))
+            raise EasyBuildError("Failed to create directory %s: %s", self.objdir, err)
 
         # generate config depending on compiler used
         toolset = self.cfg['toolset']
@@ -108,7 +117,7 @@ class EB_Boost(EasyBlock):
             elif self.toolchain.comp_family() == toolchain.GCC:
                 toolset = 'gcc'
             else:
-                self.log.error("Unknown compiler used, don't know what to specify to --with-toolset, aborting.")
+                raise EasyBuildError("Unknown compiler used, don't know what to specify to --with-toolset, aborting.")
 
         cmd = "./bootstrap.sh --with-toolset=%s --prefix=%s %s" % (toolset, self.objdir, self.cfg['configopts'])
         run_cmd(cmd, log_all=True, simple=True)
@@ -119,15 +128,56 @@ class EB_Boost(EasyBlock):
             # configure the boost mpi module
             # http://www.boost.org/doc/libs/1_47_0/doc/html/mpi/getting_started.html
             # let Boost.Build know to look here for the config file
-            f = open('user-config.jam', 'a')
-            f.write("using mpi : %s ;" % os.getenv("MPICXX"))
-            f.close()
+
+            txt = ''
+            # Check if using a Cray toolchain and configure MPI accordingly
+            if self.toolchain.toolchain_family() == toolchain.CRAYPE:
+                if self.toolchain.PRGENV_MODULE_NAME_SUFFIX == 'gnu':
+                    craympichdir = os.getenv('CRAY_MPICH2_DIR')
+                    craygccversion = os.getenv('GCC_VERSION')
+                    txt = '\n'.join([    
+                        'local CRAY_MPICH2_DIR =  %s ;' % craympichdir,
+                        'using gcc ',
+                        ': %s' % craygccversion,
+                        ': CC ',
+                        ': <compileflags>-I$(CRAY_MPICH2_DIR)/include ',
+                        '  <linkflags>-L$(CRAY_MPICH2_DIR)/lib \ ',
+                        '; ',
+                        'using mpi ',
+                        ': CC ',
+                        ': <find-shared-library>mpich ',
+                        ': %s' % self.cfg['mpi_launcher'],
+                        ';',
+                        '',
+                    ])
+                else: 
+                    raise EasyBuildError("Bailing out: only PrgEnv-gnu supported for now")
+            else:
+                txt = "using mpi : %s ;" % os.getenv("MPICXX")
+
+            write_file('user-config.jam', txt, append=True)
+
+    def build_boost_variant(self,bjamoptions,paracmd):
+        """Build Boost library with specified options for bjam."""
+        # build with specified options
+        run_cmd("./bjam %s %s" % (bjamoptions, paracmd), log_all=True, simple=True)
+        # install built Boost library
+        run_cmd("./bjam %s  install %s" % (bjamoptions, paracmd), log_all=True, simple=True)
+        # clean up before proceeding with next build    
+        run_cmd("./bjam --clean-all", log_all=True, simple=True)
 
     def build_step(self):
         """Build Boost with bjam tool."""
 
         bjamoptions = " --prefix=%s" % self.objdir
 
+        cxxflags = os.getenv('CXXFLAGS')
+        if cxxflags is not None:
+            bjamoptions += " cxxflags='%s'" % cxxflags 
+        ldflags = os.getenv('LDFLAGS')
+        if ldflags is not None:
+            bjamoptions += " linkflags='%s'" % ldflags 
+
         # specify path for bzip2/zlib if module is loaded
         for lib in ["bzip2", "zlib"]:
             libroot = get_software_root(lib)
@@ -135,22 +185,28 @@ class EB_Boost(EasyBlock):
                 bjamoptions += " -s%s_INCLUDE=%s/include" % (lib.upper(), libroot)
                 bjamoptions += " -s%s_LIBPATH=%s/lib" % (lib.upper(), libroot)
 
+        paracmd = ''
+        if self.cfg['parallel']:
+            paracmd = "-j %s" % self.cfg['parallel']
+
         if self.cfg['boost_mpi']:
             self.log.info("Building boost_mpi library")
+            self.build_boost_variant(bjamoptions + " --user-config=user-config.jam --with-mpi", paracmd)
+        
+        if self.cfg['boost_multi_thread']:
+            self.log.info("Building boost with multi threading")
+            self.build_boost_variant(bjamoptions + " threading=multi --layout=tagged", paracmd)
 
-            bjammpioptions = "%s --user-config=user-config.jam --with-mpi" % bjamoptions
-
-            # build mpi lib first
-            # let bjam know about the user-config.jam file we created in the configure step
-            run_cmd("./bjam %s" % bjammpioptions, log_all=True, simple=True)
-
-            # boost.mpi was built, let's 'install' it now
-            run_cmd("./bjam %s  install" % bjammpioptions, log_all=True, simple=True)
+        # if both boost_mpi and boost_multi_thread are enabled, build boost mpi with multi-thread support
+        if self.cfg['boost_multi_thread'] and self.cfg['boost_mpi']:
+            self.log.info("Building boost_mpi with multi threading")
+            extra_bjamoptions = " --user-config=user-config.jam --with-mpi threading=multi --layout=tagged"
+            self.build_boost_variant(bjamoptions + extra_bjamoptions, paracmd)
 
         # install remainder of boost libraries
         self.log.info("Installing boost libraries")
 
-        cmd = "./bjam %s install" % bjamoptions
+        cmd = "./bjam %s install %s" % (bjamoptions, paracmd)
         run_cmd(cmd, log_all=True, simple=True)
 
     def install_step(self):
@@ -167,20 +223,31 @@ class EB_Boost(EasyBlock):
                 else:
                     shutil.copy2(src, dst)
         except OSError, err:
-            self.log.error("Copying %s to installation dir %s failed: %s" % (self.objdir,
-                                                                             self.installdir,
-                                                                             err))
+            raise EasyBuildError("Copying %s to installation dir %s failed: %s", self.objdir, self.installdir, err)
 
     def sanity_check_step(self):
         """Custom sanity check for Boost."""
+        shlib_ext = get_shared_lib_ext()
+
         custom_paths = {
-            'files': ['lib/libboost_system.so'],
+            'files': ['lib/libboost_system.%s' % shlib_ext],
             'dirs': ['include/boost']
         }
 
         if self.cfg['boost_mpi']:
-            custom_paths["files"].append('lib/libboost_mpi.so')
+            custom_paths["files"].append('lib/libboost_mpi.%s' % shlib_ext)
         if get_software_root('Python'):
-            custom_paths["files"].append('lib/libboost_python.so')
+            custom_paths["files"].append('lib/libboost_python.%s' % shlib_ext)
+        if self.cfg['boost_multi_thread']:
+            custom_paths["files"].append('lib/libboost_thread-mt.%s' % shlib_ext)
+        if self.cfg['boost_mpi'] and self.cfg['boost_multi_thread']:
+            custom_paths["files"].append('lib/libboost_mpi-mt.%s' % shlib_ext)
 
         super(EB_Boost, self).sanity_check_step(custom_paths=custom_paths)
+
+    def make_module_extra(self):
+        """Set up a BOOST_ROOT environment variable to e.g. ease Boost handling by cmake"""
+        txt = super(EB_Boost, self).make_module_extra()
+        txt += self.module_generator.set_environment('BOOST_ROOT', self.installdir)
+        return txt
+    
