@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -31,7 +31,9 @@ EasyBuild support for CGAL, implemented as an easyblock
 import os
 
 from easybuild.easyblocks.generic.cmakemake import CMakeMake
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.modules import get_software_root
+from easybuild.tools.systemtools import get_shared_lib_ext
 
 
 class EB_CGAL(CMakeMake):
@@ -43,7 +45,7 @@ class EB_CGAL(CMakeMake):
         deps = ["Boost", "GMP", "MPFR"]
         for dep in deps:
             if not get_software_root(dep):
-                self.log.error("Dependency module %s not loaded?" % dep)
+                raise EasyBuildError("Dependency module %s not loaded?", dep)
 
         for lib in ["GMP", "MPFR"]:
             os.environ['%s_INC_DIR' % lib] = "%s%s" % (get_software_root(lib), "/include/")
@@ -55,11 +57,11 @@ class EB_CGAL(CMakeMake):
 
     def sanity_check_step(self):
         """Custom sanity check for CGAL."""
-
+        shlib_ext = get_shared_lib_ext()
+        libdirs = ('lib', 'lib64')
+        libs = [tuple(os.path.join(d, 'libCGAL%s.%s' % (l, shlib_ext)) for d in libdirs) for l in ['', '_Core']]
         custom_paths = {
-                        'files': ['bin/cgal_%s' % x for x in ["create_cmake_script", "make_macosx_app"]] +
-                                 ['lib/libCGAL%s.so' % x for x in ["", "_Core"]],
-                        'dirs':['include/CGAL', 'lib/CGAL']
-                       }
-
+            'files': ['bin/cgal_%s' % x for x in ['create_cmake_script', 'make_macosx_app']] + libs,
+            'dirs': ['include/CGAL', ('lib/CGAL', 'lib64/CGAL')],
+        }
         super(EB_CGAL, self).sanity_check_step(custom_paths=custom_paths)
