@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -31,6 +31,10 @@ EasyBuild support for building and installing CP2K, implemented as an easyblock
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
 @author: Ward Poelmans (Ghent University)
+@author: Luca Marsella (CSCS)
+@author: Damian Alvarez (Forschungszentrum Juelich GmbH)
+@author: Alan O'Cais (Forschungszentrum Juelich GmbH)
+@author: Balazs Hajgato (Free University Brussels (VUB))
 """
 
 import fileinput
@@ -44,9 +48,14 @@ from distutils.version import LooseVersion
 import easybuild.tools.toolchain as toolchain
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM
+from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.environment import setvar
+from easybuild.tools.filetools import write_file
+from easybuild.tools.config import build_option
 from easybuild.tools.modules import get_software_root, get_software_version
 from easybuild.tools.run import run_cmd
 from easybuild.tools.systemtools import get_avail_core_count
+from easybuild.tools.toolchain.compiler import OPTARCH_GENERIC
 
 # CP2K needs this version of libxc
 LIBXC_MIN_VERSION = '2.0.1'
@@ -74,37 +83,38 @@ class EB_CP2K(EasyBlock):
         self.debug = ''
         self.fpic = ''
 
+        # used for both libsmm and libxsmm
         self.libsmm = ''
         self.modincpath = ''
         self.openmp = ''
 
         self.make_instructions = ''
 
-        # always enable testing for CP2K
-        self.cfg['runtest'] = True
-
     @staticmethod
     def extra_options():
         extra_vars = {
-            'type': ['popt', "Type of build ('popt' or 'psmp')", CUSTOM],
-            'typeopt': [True, "Enable optimization", CUSTOM],
-            'modincprefix': ['', "IMKL prefix for modinc include dir", CUSTOM],
-            'modinc': [[], ("List of modinc's to use (*.f90], or 'True' to use "
-                            "all found at given prefix"), CUSTOM],
             'extracflags': ['', "Extra CFLAGS to be added", CUSTOM],
             'extradflags': ['', "Extra DFLAGS to be added", CUSTOM],
             'ignore_regtest_fails': [False, ("Ignore failures in regression test "
                                              "(should be used with care)"), CUSTOM],
-            'maxtasks': [3, ("Maximum number of CP2K instances run at "
+            'maxtasks': [4, ("Maximum number of CP2K instances run at "
                              "the same time during testing"), CUSTOM],
+            'modinc': [[], ("List of modinc's to use (*.f90], or 'True' to use "
+                            "all found at given prefix"), CUSTOM],
+            'modincprefix': ['', "IMKL prefix for modinc include dir", CUSTOM],
+            'runtest': [True, "Build and run CP2K tests", CUSTOM],
+            'omp_num_threads': [None, "Value to set $OMP_NUM_THREADS to during testing", CUSTOM],
+            'plumed': [None, "Enable PLUMED support", CUSTOM],
+            'type': ['popt', "Type of build ('popt' or 'psmp')", CUSTOM],
+            'typeopt': [True, "Enable optimization", CUSTOM],
         }
         return EasyBlock.extra_options(extra_vars)
 
     def _generate_makefile(self, options):
         """Generate Makefile based on options dictionary and optional make instructions"""
 
-        text = "# Makefile generated by CP2K._generateMakefile, items might appear in random order\n"
-        for key, value in options.iteritems():
+        text = "# Makefile generated by CP2K easyblock in EasyBuild\n"
+        for key, value in sorted(options.iteritems()):
             text += "%s = %s\n" % (key, value)
         return text + self.make_instructions
 
@@ -116,7 +126,8 @@ class EB_CP2K(EasyBlock):
 
         known_types = ['popt', 'psmp']
         if self.cfg['type'] not in known_types:
-            self.log.error("Unknown build type specified: '%s', known types are %s" % (self.cfg['type'], known_types))
+            raise EasyBuildError("Unknown build type specified: '%s', known types are %s",
+                                 self.cfg['type'], known_types)
 
         # correct start dir, if needed
         # recent CP2K versions have a 'cp2k' dir in the unpacked 'cp2k' dir
@@ -141,9 +152,14 @@ class EB_CP2K(EasyBlock):
         if self.cfg['extradflags']:
             self.log.info("Using extra CFLAGS: %s" % self.cfg['extradflags'])
 
-        # libsmm support
+        # lib(x)smm support
         libsmm = get_software_root('libsmm')
-        if libsmm:
+        libxsmm = get_software_root('libxsmm')
+        if libxsmm:
+            self.cfg.update('extradflags', '-D__LIBXSMM')
+            self.libsmm = '-lxsmm -lxsmmf'
+            self.log.debug('Using libxsmm %s' % libxsmm)
+        elif libsmm:
             libsmms = glob.glob(os.path.join(libsmm, 'lib', 'libsmm_*nn.a'))
             dfs = [os.path.basename(os.path.splitext(x)[0]).replace('lib', '-D__HAS_') for x in libsmms]
             moredflags = ' ' + ' '.join(dfs)
@@ -168,41 +184,65 @@ class EB_CP2K(EasyBlock):
         elif comp_fam == toolchain.GCC:
             options = self.configure_GCC_based()
         else:
-            self.log.error("Don't know how to tweak configuration for compiler used.")
+            raise EasyBuildError("Don't know how to tweak configuration for compiler family %s" % comp_fam)
 
-        # BLAS related
+        # BLAS/FFTW
         if get_software_root('IMKL'):
             options = self.configure_MKL(options)
-        elif get_software_root('ACML'):
-            options = self.configure_ACML(options)
         else:
-            options = self.configure_BLAS_lib(options)
+            # BLAS
+            if get_software_root('ACML'):
+                options = self.configure_ACML(options)
+            else:
+                options = self.configure_BLAS_lib(options)
 
-        if get_software_root('FFTW'):
-            options = self.configure_FFTW(options)
+            # FFTW (no MKL involved)
+            if 'fftw3' in os.getenv('LIBFFT', ''):
+                options = self.configure_FFTW3(options)
 
-        if get_software_root('LAPACK'):
+        # LAPACK
+        if os.getenv('LIBLAPACK_MT', None) is not None:
             options = self.configure_LAPACK(options)
 
-        if get_software_root('ScaLAPACK'):
+        if os.getenv('LIBSCALAPACK', None) is not None:
             options = self.configure_ScaLAPACK(options)
 
+        # PLUMED
+        plumed = get_software_root('PLUMED')
+        if self.cfg['plumed'] and not plumed:
+            raise EasyBuildError("The PLUMED module needs to be loaded to build CP2K with PLUMED support")
+
+        # enable PLUMED support if PLUMED is listed as a dependency
+        # and PLUMED support is either explicitly enabled (plumed = True) or unspecified ('plumed' not defined)
+        if plumed and (self.cfg['plumed'] or self.cfg['plumed'] is None):
+            options['LIBS'] += ' -lplumed'
+            options['DFLAGS'] += ' -D__PLUMED2'
+
+        # ELPA
+        elpa = get_software_root('ELPA')
+        if elpa:
+            options['LIBS'] += ' -lelpa'
+            options['DFLAGS'] += ' -D__ELPA3'
+            elpa_inc_dir = os.path.join(elpa, 'include', 'elpa-%s' % get_software_version('ELPA'), 'modules')
+            options['FCFLAGSOPT'] += ' -I%s ' % elpa_inc_dir
+
+        # CUDA
+        cuda = get_software_root('CUDA')
+        if cuda:
+            options['DFLAGS'] += ' -D__ACC -D__DBCSR_ACC'
+            options['LIBS'] += ' -lcudart -lcublas -lcufft -lrt'
+            options['NVCC'] = ' nvcc'
+
         # avoid group nesting
         options['LIBS'] = options['LIBS'].replace('-Wl,--start-group', '').replace('-Wl,--end-group', '')
 
         options['LIBS'] = "-Wl,--start-group %s -Wl,--end-group" % options['LIBS']
 
         # create arch file using options set
-        archfile = os.path.join(self.cfg['start_dir'], 'arch',
-                                '%s.%s' % (self.typearch, self.cfg['type']))
-        try:
-            txt = self._generate_makefile(options)
-            f = open(archfile, 'w')
-            f.write(txt)
-            f.close()
-            self.log.info("Content of makefile (%s):\n%s" % (archfile, txt))
-        except IOError, err:
-            self.log.error("Writing makefile %s failed: %s" % (archfile, err))
+        archfile = os.path.join(self.cfg['start_dir'], 'arch', '%s.%s' % (self.typearch, self.cfg['type']))
+        txt = self._generate_makefile(options)
+        write_file(archfile, txt)
+        self.log.info("Content of makefile (%s):\n%s" % (archfile, txt))
 
     def prepmodinc(self):
         """Prepare list of module files"""
@@ -220,7 +260,7 @@ class EB_CP2K(EasyBlock):
             try:
                 os.mkdir(modincpath)
             except OSError, err:
-                self.log.error("Failed to create directory for module include files: %s" % err)
+                raise EasyBuildError("Failed to create directory for module include files: %s", err)
 
             # get list of modinc source files
             modincdir = os.path.join(imkl, self.cfg["modincprefix"], 'include')
@@ -232,12 +272,12 @@ class EB_CP2K(EasyBlock):
                 modfiles = glob.glob(os.path.join(modincdir, '*.f90'))
 
             else:
-                self.log.error("prepmodinc: Please specify either a boolean value "
-                               "or a list of files in modinc (found: %s)." % self.cfg["modinc"])
+                raise EasyBuildError("prepmodinc: Please specify either a boolean value or a list of files in modinc "
+                                     "(found: %s).", self.cfg["modinc"])
 
             f77 = os.getenv('F77')
             if not f77:
-                self.log.error("F77 environment variable not set, can't continue.")
+                raise EasyBuildError("F77 environment variable not set, can't continue.")
 
             # create modinc files
             for f in modfiles:
@@ -246,13 +286,13 @@ class EB_CP2K(EasyBlock):
                 elif f77 in ['gfortran', 'mpif77']:
                     cmd = "%s -J%s -c %s" % (f77, modincpath, f)
                 else:
-                    self.log.error("prepmodinc: Unknown value specified for F77 (%s)" % f77)
+                    raise EasyBuildError("prepmodinc: Unknown value specified for F77 (%s)", f77)
 
                 run_cmd(cmd, log_all=True, simple=True)
 
             return modincpath
         else:
-            self.log.error("Don't know how to prepare modinc, IMKL not found")
+            raise EasyBuildError("Don't know how to prepare modinc, IMKL not found")
 
     def configure_common(self):
         """Common configuration for all toolchains"""
@@ -272,16 +312,35 @@ class EB_CP2K(EasyBlock):
             regflags = 'NOOPT'
 
         # make sure a MPI-2 able MPI lib is used
-        mpi2libs = ['impi', 'MVAPICH2', 'OpenMPI']
         mpi2 = False
-        for mpi2lib in mpi2libs:
-            if get_software_root(mpi2lib):
+        if hasattr(self.toolchain, 'MPI_FAMILY') and self.toolchain.MPI_FAMILY is not None:
+            known_mpi2_fams = [toolchain.MPICH, toolchain.MPICH2, toolchain.MVAPICH2, toolchain.OPENMPI,
+                               toolchain.INTELMPI]
+            mpi_fam = self.toolchain.mpi_family()
+            if mpi_fam in known_mpi2_fams:
                 mpi2 = True
+                self.log.debug("Determined MPI2 compatibility based on MPI toolchain component: %s" % mpi_fam)
             else:
-                self.log.debug("MPI-2 supporting MPI library %s not loaded.")
+                self.log.debug("Cannot determine MPI2 compatibility based on MPI toolchain component: %s" % mpi_fam)
+        else:
+            # can't use toolchain.mpi_family, because of dummy toolchain
+            mpi2libs = ['impi', 'MVAPICH2', 'OpenMPI', 'MPICH2', 'MPICH']
+            for mpi2lib in mpi2libs:
+                if get_software_root(mpi2lib):
+                    mpi2 = True
+                    self.log.debug("Determined MPI2 compatibility based on loaded MPI module: %s")
+                else:
+                    self.log.debug("MPI-2 supporting MPI library %s not loaded.")
 
         if not mpi2:
-            self.log.error("CP2K needs MPI-2, no known MPI-2 supporting library loaded?")
+            raise EasyBuildError("CP2K needs MPI-2, no known MPI-2 supporting library loaded?")
+
+        # pick up optarch value from toolchain, when optarch toolchain option is enabled or --optarch=GENERIC is used
+        optarch = ''
+        if self.toolchain.options.get('optarch', False) or build_option('optarch') == OPTARCH_GENERIC:
+            # take into account that a '-' is missing for the first compiler flag, but also that optarch may be empty
+            if self.toolchain.options.option('optarch'):
+                optarch = '-%s' % self.toolchain.options.option('optarch')
 
         options = {
             'CC': os.getenv('MPICC'),
@@ -297,16 +356,15 @@ class EB_CP2K(EasyBlock):
             'FCFLAGS': '$(FCFLAGS%s)' % optflags,
             'FCFLAGS2': '$(FCFLAGS%s)' % regflags,
 
-            'CFLAGS': ' %s %s $(FPIC) $(DEBUG) %s ' % (os.getenv('EBVARCPPFLAGS'),
-                                                       os.getenv('EBVARLDFLAGS'),
+            'CFLAGS': ' %s %s $(FPIC) $(DEBUG) %s ' % (os.getenv('CPPFLAGS'), os.getenv('LDFLAGS'),
                                                        self.cfg['extracflags']),
             'DFLAGS': ' -D__parallel -D__BLACS -D__SCALAPACK -D__FFTSG %s' % self.cfg['extradflags'],
 
-            'LIBS': os.getenv('LIBS'),
+            'LIBS': os.getenv('LIBS', ''),
 
             'FCFLAGSNOOPT': '$(DFLAGS) $(CFLAGS) -O0  $(FREE) $(FPIC) $(DEBUG)',
-            'FCFLAGSOPT': '-O2 $(FREE) $(SAFE) $(FPIC) $(DEBUG)',
-            'FCFLAGSOPT2': '-O1 $(FREE) $(SAFE) $(FPIC) $(DEBUG)'
+            'FCFLAGSOPT': '-O2 $(FREE) $(SAFE) $(FPIC) $(DEBUG) %s' % optarch,
+            'FCFLAGSOPT2': '-O1 $(FREE) $(SAFE) $(FPIC) $(DEBUG) %s' % optarch,
         }
 
         libint = get_software_root('LibInt')
@@ -331,12 +389,12 @@ class EB_CP2K(EasyBlock):
                         libinttools_path = path
                         os.chdir(libinttools_path)
                 if not libinttools_path:
-                    self.log.error("No libinttools dir found")
+                    raise EasyBuildError("No libinttools dir found")
 
                 # build libint wrapper
                 cmd = "%s -c libint_cpp_wrapper.cpp -I%s/include" % (libintcompiler, libint)
                 if not run_cmd(cmd, log_all=True, simple=True):
-                    self.log.error("Building the libint wrapper failed")
+                    raise EasyBuildError("Building the libint wrapper failed")
                 libint_wrapper = '%s/libint_cpp_wrapper.o' % libinttools_path
 
             # determine LibInt libraries based on major version number
@@ -346,7 +404,7 @@ class EB_CP2K(EasyBlock):
             elif libint_maj_ver == '2':
                 libint_libs = "$(LIBINTLIB)/libint2.a"
             else:
-                self.log.error("Don't know how to handle libint version %s" % libint_maj_ver)
+                raise EasyBuildError("Don't know how to handle libint version %s", libint_maj_ver)
             self.log.info("Using LibInt version %s" % (libint_maj_ver))
 
             options['LIBINTLIB'] = '%s/lib' % libint
@@ -356,12 +414,12 @@ class EB_CP2K(EasyBlock):
             # throw a warning, since CP2K without LibInt doesn't make much sense
             self.log.warning("LibInt module not loaded, so building without LibInt support")
 
-            
+
         libxc = get_software_root('libxc')
         if libxc:
             cur_libxc_version = get_software_version('libxc')
             if LooseVersion(cur_libxc_version) < LooseVersion(LIBXC_MIN_VERSION):
-                self.log.error("CP2K only works with libxc v%s (or later)" % LIBXC_MIN_VERSION)
+                raise EasyBuildError("CP2K only works with libxc v%s (or later)", LIBXC_MIN_VERSION)
 
             options['DFLAGS'] += ' -D__LIBXC2'
             if LooseVersion(cur_libxc_version) >= LooseVersion('2.2'):
@@ -397,20 +455,27 @@ class EB_CP2K(EasyBlock):
 
             'INCFLAGS': '$(DFLAGS) -I$(INTEL_INC) -I$(INTEL_INCF) %s' % extrainc,
 
-            'LDFLAGS': '$(INCFLAGS) -i-static',
+            'LDFLAGS': '$(INCFLAGS) ',
             'OBJECTS_ARCHITECTURE': 'machine_intel.o',
         })
 
         options['DFLAGS'] += ' -D__INTEL'
 
-        optarch = ''
-        if self.toolchain.options['optarch']:
-            optarch = '-xHOST'
-
-        options['FCFLAGSOPT'] += ' $(INCFLAGS) %s -heap-arrays 64' % optarch
-        options['FCFLAGSOPT2'] += ' $(INCFLAGS) %s -heap-arrays 64' % optarch
+        options['FCFLAGSOPT'] += ' $(INCFLAGS) -heap-arrays 64'
+        options['FCFLAGSOPT2'] += ' $(INCFLAGS) -heap-arrays 64'
 
         ifortver = LooseVersion(get_software_version('ifort'))
+
+        # -i-static has been deprecated prior to 2013, but was still usable. From 2015 it is not.
+        if ifortver < LooseVersion("2013"):
+            options['LDFLAGS'] += ' -i-static '
+        else:
+            options['LDFLAGS'] += ' -static-intel '
+
+        # Otherwise it fails on linking, since there are 2 definitions of main
+        if LooseVersion(self.version) >= LooseVersion('4.1'):
+            options['LDFLAGS'] += ' -nofor-main '
+
         failmsg = "CP2K won't build correctly with the Intel %%s compilers prior to %%s, see %s" % intelurl
 
         if ifortver >= LooseVersion("2011") and ifortver < LooseVersion("2012"):
@@ -422,17 +487,17 @@ class EB_CP2K(EasyBlock):
                 self.make_instructions += "qs_vxc_atom.o: qs_vxc_atom.F\n\t$(FC) -c $(FCFLAGS2) $<\n"
 
             else:
-                self.log.error(failmsg % ("v12", "v2011.8"))
+                raise EasyBuildError(failmsg, "v12", "v2011.8")
 
         elif ifortver >= LooseVersion("11"):
             if LooseVersion(get_software_version('ifort')) >= LooseVersion("11.1.072"):
                 self.make_instructions += "qs_vxc_atom.o: qs_vxc_atom.F\n\t$(FC) -c $(FCFLAGS2) $<\n"
 
             else:
-                self.log.error(failmsg % ("v11", "v11.1.072"))
+                raise EasyBuildError(failmsg, "v11", "v11.1.072")
 
         else:
-            self.log.error("Intel compilers version %s not supported yet." % ifortver)
+            raise EasyBuildError("Intel compilers version %s not supported yet.", ifortver)
 
         return options
 
@@ -450,12 +515,8 @@ class EB_CP2K(EasyBlock):
 
         options['DFLAGS'] += ' -D__GFORTRAN'
 
-        optarch = ''
-        if self.toolchain.options['optarch']:
-            optarch = '-march=native'
-
-        options['FCFLAGSOPT'] += ' $(DFLAGS) $(CFLAGS) %s -fmax-stack-var-size=32768' % optarch
-        options['FCFLAGSOPT2'] += ' $(DFLAGS) $(CFLAGS) %s' % optarch
+        options['FCFLAGSOPT'] += ' $(DFLAGS) $(CFLAGS) -fmax-stack-var-size=32768'
+        options['FCFLAGSOPT2'] += ' $(DFLAGS) $(CFLAGS)'
 
         return options
 
@@ -470,17 +531,15 @@ class EB_CP2K(EasyBlock):
         options['CFLAGS'] += ' -I$(ACML_INC) -I$(FFTW_INC)'
         options['DFLAGS'] += ' -D__FFTACML'
 
-        blas = os.getenv('LIBBLAS')
+        blas = os.getenv('LIBBLAS', '')
         blas = blas.replace('gfortran64', 'gfortran64%s' % openmp_suffix)
-        options['LIBS'] += ' %s %s %s' % (self.libsmm, os.getenv('LIBSCALAPACK'), blas)
+        options['LIBS'] += ' %s %s %s' % (self.libsmm, os.getenv('LIBSCALAPACK', ''), blas)
 
         return options
 
     def configure_BLAS_lib(self, options):
         """Configure for BLAS library."""
-
-        options['LIBS'] += ' %s %s' % (self.libsmm, os.getenv('LIBBLAS'))
-
+        options['LIBS'] += ' %s %s' % (self.libsmm, os.getenv('LIBBLAS', ''))
         return options
 
     def configure_MKL(self, options):
@@ -497,7 +556,7 @@ class EB_CP2K(EasyBlock):
             extra = '-I%s' % self.modincpath
         options['CFLAGS'] += ' -I$(INTEL_INC) %s $(FPIC) $(DEBUG)' % extra
 
-        options['LIBS'] += ' %s %s' % (self.libsmm, os.getenv('LIBSCALAPACK'))
+        options['LIBS'] += ' %s %s' % (self.libsmm, os.getenv('LIBSCALAPACK', ''))
 
         # only use Intel FFTW wrappers if FFTW is not loaded
         if not get_software_root('FFTW'):
@@ -510,38 +569,37 @@ class EB_CP2K(EasyBlock):
 
             options['CFLAGS'] += ' -I$(INTEL_INCF)'
 
-            options['LIBS'] = '%s %s' % (os.getenv('LIBFFT'), options['LIBS'])
+            options['LIBS'] = '%s %s' % (os.getenv('LIBFFT', ''), options['LIBS'])
 
         return options
 
-    def configure_FFTW(self, options):
-        """Configure for Fastest Fourier Transform in the West (FFTW)"""
-
-        fftw = get_software_root('FFTW')
+    def configure_FFTW3(self, options):
+        """Configure for FFTW3"""
 
         options.update({
-            'FFTW_INC': '%s/include' % fftw,  # GCC
-            'FFTW3INC': '%s/include' % fftw,  # Intel
-            'FFTW3LIB': '%s/lib' % fftw,  # Intel
+            'FFTW_INC': os.getenv('FFT_INC_DIR', ''),  # GCC
+            'FFTW3INC': os.getenv('FFT_INC_DIR', ''),  # Intel
+            'FFTW3LIB': os.getenv('FFT_LIB_DIR', ''),  # Intel
         })
 
         options['DFLAGS'] += ' -D__FFTW3'
-
-        options['LIBS'] += ' -L%s -lfftw3' % os.path.join(os.getenv('EBROOTFFTW'), 'lib')
+        if self.cfg['type'] == 'psmp':
+            libfft = os.getenv('LIBFFT_MT', '')
+        else:
+            libfft = os.getenv('LIBFFT', '')
+        options['LIBS'] += ' -L%s %s' % (os.getenv('FFT_LIB_DIR', '.'), libfft)
 
         return options
 
     def configure_LAPACK(self, options):
         """Configure for LAPACK library"""
-
-        options['LIBS'] += ' %s' % os.getenv('LIBLAPACK_MT')
-
+        options['LIBS'] += ' %s' % os.getenv('LIBLAPACK_MT', '')
         return options
 
     def configure_ScaLAPACK(self, options):
         """Configure for ScaLAPACK library"""
 
-        options['LIBS'] += ' %s' % os.getenv('LIBSCALAPACK')
+        options['LIBS'] += ' %s' % os.getenv('LIBSCALAPACK', '')
 
         return options
 
@@ -555,8 +613,8 @@ class EB_CP2K(EasyBlock):
         makefiles = os.path.join(self.cfg['start_dir'], 'makefiles')
         try:
             os.chdir(makefiles)
-        except:
-            self.log.error("Can't change to makefiles dir %s: %s" % (makefiles))
+        except OSError, err:
+            raise EasyBuildError("Can't change to makefiles dir %s: %s", makefiles, err)
 
         # modify makefile for parallel build
         parallel = self.cfg['parallel']
@@ -567,7 +625,7 @@ class EB_CP2K(EasyBlock):
                     line = re.sub(r"^PMAKE\s*=.*$", "PMAKE\t= $(SMAKE) -j %s" % parallel, line)
                     sys.stdout.write(line)
             except IOError, err:
-                self.log.error("Can't modify/write Makefile in %s: %s" % (makefiles, err))
+                raise EasyBuildError("Can't modify/write Makefile in %s: %s", makefiles, err)
 
         # update make options with MAKE
         self.cfg.update('buildopts', 'MAKE="make -j %s" all' % self.cfg['parallel'])
@@ -588,11 +646,18 @@ class EB_CP2K(EasyBlock):
 
         if self.cfg['runtest']:
 
+            if not build_option('mpi_tests'):
+                self.log.info("Skipping testing of CP2K since MPI testing is disabled")
+                return
+
+            if self.cfg['omp_num_threads']:
+                setvar('OMP_NUM_THREADS', self.cfg['omp_num_threads'])
+
             # change to root of build dir
             try:
                 os.chdir(self.builddir)
             except OSError, err:
-                self.log.error("Failed to change to %s: %s" % self.builddir)
+                raise EasyBuildError("Failed to change to %s: %s", self.builddir, err)
 
             # use regression test reference output if available
             # try and find an unpacked directory that starts with 'LAST-'
@@ -619,14 +684,14 @@ class EB_CP2K(EasyBlock):
                         line = re.sub(r"^(dir_last\s*=\${dir_base})/.*$", r"\1/%s" % regtest_refdir, line)
                         sys.stdout.write(line)
                 except IOError, err:
-                    self.log.error("Failed to modify '%s': %s" % (regtest_script, err))
+                    raise EasyBuildError("Failed to modify '%s': %s", regtest_script, err)
 
             else:
                 self.log.info("No reference output found for regression test, just continuing without it...")
 
             test_core_cnt = min(self.cfg.get('parallel', sys.maxint), 2)
             if get_avail_core_count() < test_core_cnt:
-                self.log.error("Cannot run MPI tests as not enough cores (< %s) are available" % test_core_cnt)
+                raise EasyBuildError("Cannot run MPI tests as not enough cores (< %s) are available", test_core_cnt)
             else:
                 self.log.info("Using %s cores for the MPI tests" % test_core_cnt)
 
@@ -651,13 +716,7 @@ class EB_CP2K(EasyBlock):
                 'mpicmd_prefix': self.toolchain.mpi_cmd_for('', test_core_cnt),
             }
 
-            try:
-                f = open(cfg_fn, "w")
-                f.write(cfg_txt)
-                f.close()
-            except IOError, err:
-                self.log.error("Failed to create config file %s: %s" % (cfg_fn, err))
-
+            write_file(cfg_fn, cfg_txt)
             self.log.debug("Contents of %s: %s" % (cfg_fn, cfg_txt))
 
             # run regression test
@@ -666,7 +725,7 @@ class EB_CP2K(EasyBlock):
             if ec == 0:
                 self.log.info("Regression test output:\n%s" % regtest_output)
             else:
-                self.log.error("Regression test failed (non-zero exit code): %s" % regtest_output)
+                raise EasyBuildError("Regression test failed (non-zero exit code): %s", regtest_output)
 
             # pattern to search for regression test summary
             re_pattern = "number\s+of\s+%s\s+tests\s+(?P<cnt>[0-9]+)"
@@ -678,8 +737,7 @@ class EB_CP2K(EasyBlock):
             if res:
                 tot_cnt = int(res.group('cnt'))
             else:
-                self.log.error("Finding total number of tests in regression test summary failed")
-            msg = "Regression test reported %%s / %s %%s tests" % tot_cnt
+                raise EasyBuildError("Finding total number of tests in regression test summary failed")
 
             # function to report on regtest results
             def test_report(test_result):
@@ -693,24 +751,26 @@ class EB_CP2K(EasyBlock):
                 cnt = None
                 res = regexp.search(regtest_output)
                 if not res:
-                    self.log.error("Finding number of %s tests in regression test summary failed" % test_result.lower())
+                    raise EasyBuildError("Finding number of %s tests in regression test summary failed",
+                                         test_result.lower())
                 else:
                     cnt = int(res.group('cnt'))
 
-                logmsg = msg % (cnt, test_result.lower())
+                logmsg = "Regression test reported %s / %s %s tests"
+                logmsg_values = (cnt, tot_cnt, test_result.lower())
 
                 # failed tests indicate problem with installation
                 # wrong tests are only an issue when there are excessively many
                 if (test_result == "FAILED" and cnt > 0) or (test_result == "WRONG" and (cnt / tot_cnt) > 0.1):
                     if self.cfg['ignore_regtest_fails']:
-                        self.log.warning(logmsg)
+                        self.log.warning(logmsg, *logmsg_values)
                         self.log.info("Ignoring failures in regression test, as requested.")
                     else:
-                        self.log.error(logmsg)
+                        raise EasyBuildError(logmsg, *logmsg_values)
                 elif test_result == "CORRECT" or cnt == 0:
-                    self.log.info(logmsg)
+                    self.log.info(logmsg, *logmsg_values)
                 else:
-                    self.log.warning(logmsg)
+                    self.log.warning(logmsg, *logmsg_values)
 
                 return postmsg
 
@@ -728,6 +788,7 @@ class EB_CP2K(EasyBlock):
     def install_step(self):
         """Install built CP2K
         - copy from exe to bin
+        - copy data dir (if exists)
         - copy tests
         """
 
@@ -742,7 +803,20 @@ class EB_CP2K(EasyBlock):
                 if os.path.isfile(exefile):
                     shutil.copy2(exefile, targetdir)
         except OSError, err:
-            self.log.error("Copying executables from %s to bin dir %s failed: %s" % (exedir, targetdir, err))
+            raise EasyBuildError("Copying executables from %s to bin dir %s failed: %s", exedir, targetdir, err)
+
+        # copy data dir
+        datadir = os.path.join(self.cfg['start_dir'], 'data')
+        targetdir = os.path.join(self.installdir, 'data')
+        if os.path.exists(targetdir):
+            self.log.info("Won't copy data dir. Destination directory %s already exists" % targetdir)
+        elif os.path.exists(datadir):
+            try:
+                shutil.copytree(datadir, targetdir)
+            except:
+                raise EasyBuildError("Copying data dir from %s to %s failed", datadir, targetdir)
+        else:
+            self.log.info("Won't copy data dir. Source directory %s does not exist" % datadir)
 
         # copy tests
         srctests = os.path.join(self.cfg['start_dir'], 'tests')
@@ -753,7 +827,7 @@ class EB_CP2K(EasyBlock):
             try:
                 shutil.copytree(srctests, targetdir)
             except:
-                self.log.error("Copying tests from %s to %s failed" % (srctests, targetdir))
+                raise EasyBuildError("Copying tests from %s to %s failed", srctests, targetdir)
 
         # copy regression test results
         if self.cfg['runtest']:
@@ -767,15 +841,24 @@ class EB_CP2K(EasyBlock):
                         self.log.info("Regression test results dir %s copied to %s" % (d, self.installdir))
                         break
             except (OSError, IOError), err:
-                self.log.error("Failed to copy regression test results dir: %s" % err)
+                raise EasyBuildError("Failed to copy regression test results dir: %s", err)
 
     def sanity_check_step(self):
         """Custom sanity check for CP2K"""
 
         cp2k_type = self.cfg['type']
         custom_paths = {
-            'files': ["bin/%s.%s" % (x, cp2k_type) for x in ["cp2k", "cp2k_shell", "fes"]],
+            'files': ["bin/%s.%s" % (x, cp2k_type) for x in ["cp2k", "cp2k_shell"]],
             'dirs': ["tests"]
         }
 
         super(EB_CP2K, self).sanity_check_step(custom_paths=custom_paths)
+
+    def make_module_extra(self):
+        """Set up a CP2K_DATA_DIR environment variable to find CP2K provided basis sets"""
+
+        txt = super(EB_CP2K, self).make_module_extra()
+        datadir = os.path.join(self.installdir, 'data')
+        if os.path.exists(datadir):
+            txt += self.module_generator.set_environment('CP2K_DATA_DIR', datadir)
+        return txt
