@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -39,6 +39,7 @@ import stat
 import easybuild.tools.environment as env
 from easybuild.easyblocks.generic.binary import Binary
 from easybuild.framework.easyconfig import CUSTOM
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.run import run_cmd_qa
 
 
@@ -51,15 +52,7 @@ class EB_CPLEX(Binary):
     def __init__(self, *args, **kwargs):
         """Initialize CPLEX-specific variables."""
         super(EB_CPLEX, self).__init__(*args, **kwargs)
-        self.bindir = None
-
-    @staticmethod
-    def extra_options():
-        extra_vars = {
-            # staged install via a tmp dir can help with the hard (potentially faulty) check on available disk space
-            'staged_install': [False, "Should the installation should be staged via a temporary dir?", CUSTOM],
-        }
-        return Binary.extra_options(extra_vars)
+        self.bindir = 'UNKNOWN'
 
     def install_step(self):
         """CPLEX has an interactive installer, so use Q&A"""
@@ -71,23 +64,19 @@ class EB_CPLEX(Binary):
             os.makedirs(tmpdir)
             os.makedirs(stagedir)
         except OSError, err:
-            self.log.exception("Failed to prepare for installation: %s" % err)
+            raise EasyBuildError("Failed to prepare for installation: %s", err)
 
         env.setvar('IATEMPDIR', tmpdir)
         dst = os.path.join(self.builddir, self.src[0]['name'])
 
         cmd = "%s -i console" % dst
 
-        install_target = self.installdir
-        if self.cfg['staged_install']:
-            install_target = stagedir
-
         qanda = {
             "PRESS <ENTER> TO CONTINUE:": '',
             'Press Enter to continue viewing the license agreement, or enter' \
             ' "1" to accept the agreement, "2" to decline it, "3" to print it,' \
             ' or "99" to go back to the previous screen.:': '1',
-            'ENTER AN ABSOLUTE PATH, OR PRESS <ENTER> TO ACCEPT THE DEFAULT :': install_target,
+            'ENTER AN ABSOLUTE PATH, OR PRESS <ENTER> TO ACCEPT THE DEFAULT :': self.installdir,
             'IS THIS CORRECT? (Y/N):': 'y',
             'PRESS <ENTER> TO INSTALL:': '',
             "PRESS <ENTER> TO EXIT THE INSTALLER:": '',
@@ -98,19 +87,15 @@ class EB_CPLEX(Binary):
 
         run_cmd_qa(cmd, qanda, no_qa=noqanda, log_all=True, simple=True)
 
-        if self.cfg['staged_install']:
-            # move staged installation to actual install dir
-            try:
-                # copytree expects target directory to not exist yet
-                shutil.rmtree(self.installdir)
-                shutil.copytree(stagedir, self.installdir)
-            except OSError, err:
-                self.log.error("Failed to move staged install from %s to %s: %s" % (stagedir, self.installdir, err))
-
         try:
             os.chmod(self.installdir, stat.S_IRWXU | stat.S_IXOTH | stat.S_IXGRP | stat.S_IROTH | stat.S_IRGRP)
         except OSError, err:
-            self.log.exception("Can't set permissions on %s: %s" % (self.installdir, err))
+            raise EasyBuildError("Can't set permissions on %s: %s", self.installdir, err)
+
+    def post_install_step(self):
+        """Determine bin directory for this CPLEX installation."""
+        # handle staged install via Binary parent class
+        super(EB_CPLEX, self).post_install_step()
 
         # determine bin dir
         os.chdir(self.installdir)
@@ -120,25 +105,36 @@ class EB_CPLEX(Binary):
         if len(bins) == 1:
             self.bindir = bins[0]
         elif len(bins) > 1:
-            self.log.error("More than one possible path for bin found: %s" % bins)
+            raise EasyBuildError("More than one possible path for bin found: %s", bins)
         else:
-            self.log.error("No bins found using %s in %s" % (binglob, self.installdir))
+            raise EasyBuildError("No bins found using %s in %s", binglob, self.installdir)
 
     def make_module_extra(self):
-        """Add installdir to path and set CPLEX_HOME"""
-
+        """Add bin dirs and lib dirs and set CPLEX_HOME and CPLEXDIR"""
         txt = super(EB_CPLEX, self).make_module_extra()
-        txt += self.module_generator.prepend_paths("PATH", [self.bindir])
-        txt += self.module_generator.set_environment("CPLEX_HOME", "$root/cplex")
+
+        try:
+            cwd = os.getcwd()
+            os.chdir(self.installdir)
+            bins = glob.glob(os.path.join('*', 'bin', 'x86-64*'))
+            libs = glob.glob(os.path.join('*', 'lib', 'x86-64*', '*pic'))
+            os.chdir(cwd)
+        except OSError as err:
+            raise EasyBuildError("Failed to determine bin/lib subdirs: %s", err)
+
+        txt += self.module_generator.prepend_paths('PATH', [path for path in bins])
+        txt += self.module_generator.prepend_paths('LD_LIBRARY_PATH', [path for path in bins+libs])
+
+        txt += self.module_generator.set_environment('CPLEX_HOME', os.path.join(self.installdir, 'cplex'))
+        txt += self.module_generator.set_environment('CPLEXDIR', os.path.join(self.installdir, 'cplex'))
+
         self.log.debug("make_module_extra added %s" % txt)
         return txt
 
     def sanity_check_step(self):
         """Custom sanity check for CPLEX"""
-
         custom_paths = {
             'files':["%s/%s" % (self.bindir, x) for x in ["convert", "cplex", "cplexamp"]],
             'dirs':[],
         }
-
         super(EB_CPLEX, self).sanity_check_step(custom_paths=custom_paths)
