@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -27,10 +27,12 @@ EasyBuild support for building and installing flex, implemented as an easyblock
 
 @author: Kenneth Hoste (Ghent University)
 """
-
+from distutils.version import LooseVersion
 import os
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
+from easybuild.tools.build_log import EasyBuildError
+
 
 class EB_flex(ConfigureMake):
     """Support for building and installing flex."""
@@ -47,15 +49,16 @@ class EB_flex(ConfigureMake):
                     os.symlink(os.path.join(self.installdir, "bin", "flex"), binpath)
 
         except OSError, err:
-            self.log.error("Failed to symlink binaries: %s" % err)
+            raise EasyBuildError("Failed to symlink binaries: %s", err)
 
     def sanity_check_step(self):
         """Custom sanity check for flex"""
-
         custom_paths =  {
-                         'files':["bin/%s" % x for x in ["flex", "lex", "lex++"]] + ["include/FlexLexer.h"] +
-                                 ["lib/lib%s.a" % x for x in ["fl", "fl_pic"]],
-                         'dirs':[]
-                        }
+            'files': [os.path.join('bin', x) for x in ['flex', 'lex', 'lex++']] + ['include/FlexLexer.h'] +
+                     [('lib/libfl.a', 'lib64/libfl.a')],
+            'dirs':[]
+        }
+        if LooseVersion(self.version) < LooseVersion('2.6.3'):
+            custom_paths['files'].append(('lib/libfl_pic.a', 'lib64/libfl_pic.a'))
 
         super(EB_flex, self).sanity_check_step(custom_paths=custom_paths)
