@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2014 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -34,8 +34,8 @@ EasyBuild support for building and installing GCC, implemented as an easyblock
 @author: Ward Poelmans (Ghent University)
 """
 
-import re
 import os
+import re
 import shutil
 from copy import copy
 from distutils.version import LooseVersion
@@ -44,6 +44,8 @@ from vsc.utils.missing import any
 import easybuild.tools.environment as env
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.framework.easyconfig import CUSTOM
+from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.filetools import write_file
 from easybuild.tools.modules import get_software_root
 from easybuild.tools.run import run_cmd
 from easybuild.tools.systemtools import check_os_dependency, get_os_name, get_os_type, get_shared_lib_ext, get_platform_name
@@ -59,6 +61,7 @@ class EB_GCC(ConfigureMake):
     def extra_options():
         extra_vars = {
             'languages': [[], "List of languages to build GCC for (--enable-languages)", CUSTOM],
+            'withlibiberty': [False, "Enable installing of libiberty", CUSTOM],
             'withlto': [True, "Enable LTO support", CUSTOM],
             'withcloog': [False, "Build GCC with CLooG support", CUSTOM],
             'withppl': [False, "Build GCC with PPL support", CUSTOM],
@@ -66,6 +69,7 @@ class EB_GCC(ConfigureMake):
             'pplwatchdog': [False, "Enable PPL watchdog", CUSTOM],
             'clooguseisl': [False, "Use ISL with CLooG or not", CUSTOM],
             'multilib': [False, "Build multilib gcc (both i386 and x86_64)", CUSTOM],
+            'prefer_lib_subdir': [False, "Configure GCC to prefer 'lib' subdirs over 'lib64' & co when linking", CUSTOM],
         }
         return ConfigureMake.extra_options(extra_vars)
 
@@ -74,12 +78,13 @@ class EB_GCC(ConfigureMake):
 
         self.stagedbuild = False
 
-        if self.version >= LooseVersion("4.8.0") and self.cfg['clooguseisl'] and not self.cfg['withisl']:
-            self.log.error("Using ISL bundled with CLooG is unsupported in >=GCC-4.8.0. Use a seperate ISL: set withisl=True")
+        if LooseVersion(self.version) >= LooseVersion("4.8.0") and self.cfg['clooguseisl'] and not self.cfg['withisl']:
+            raise EasyBuildError("Using ISL bundled with CLooG is unsupported in >=GCC-4.8.0. "
+                                 "Use a seperate ISL: set withisl=True")
 
-        # I think ISL without CLooG has no purpose in GCC...
-        if self.cfg['withisl'] and not self.cfg['withcloog']:
-            self.log.error("Activating ISL without CLooG is pointless")
+        # I think ISL without CLooG has no purpose in GCC < 5.0.0 ...
+        if LooseVersion(self.version) < LooseVersion("5.0.0") and self.cfg['withisl'] and not self.cfg['withcloog']:
+            raise EasyBuildError("Activating ISL without CLooG is pointless")
 
         # unset some environment variables that are known to may cause nasty build errors when bootstrapping
         self.cfg.update('unwanted_env_vars', ['CPATH', 'C_INCLUDE_PATH', 'CPLUS_INCLUDE_PATH', 'OBJC_INCLUDE_PATH'])
@@ -87,6 +92,8 @@ class EB_GCC(ConfigureMake):
         if get_os_name() not in ['ubuntu', 'debian']:
             self.cfg.update('unwanted_env_vars', ['LIBRARY_PATH'])
 
+        self.platform_lib = get_platform_name(withversion=True)
+
     def create_dir(self, dirname):
         """
         Create a dir to build in.
@@ -98,7 +105,7 @@ class EB_GCC(ConfigureMake):
             self.log.debug("Created dir at %s" % dirpath)
             return dirpath
         except OSError, err:
-            self.log.error("Can't use dir %s to build in: %s" % (dirpath, err))
+            raise EasyBuildError("Can't use dir %s to build in: %s", dirpath, err)
 
     def prep_extra_src_dirs(self, stage, target_prefix=None):
         """
@@ -107,7 +114,7 @@ class EB_GCC(ConfigureMake):
         if LooseVersion(self.version) >= LooseVersion('4.5'):
             known_stages = ["stage1", "stage2", "stage3"]
             if stage not in known_stages:
-                self.log.error("Incorrect argument for prep_extra_src_dirs, should be one of: %s" % known_stages)
+                raise EasyBuildError("Incorrect argument for prep_extra_src_dirs, should be one of: %s", known_stages)
 
             configopts = ''
             if stage == "stage2":
@@ -164,7 +171,8 @@ class EB_GCC(ConfigureMake):
 
             # we need to find all dirs specified, or else...
             if not len(found_src_dirs) == len(extra_src_dirs):
-                self.log.error("Couldn't find all source dirs %s: found %s from %s" % (extra_src_dirs, found_src_dirs, all_dirs))
+                raise EasyBuildError("Couldn't find all source dirs %s: found %s from %s",
+                                     extra_src_dirs, found_src_dirs, all_dirs)
 
             # copy to a dir with name as expected by GCC build framework
             for d in found_src_dirs:
@@ -177,7 +185,7 @@ class EB_GCC(ConfigureMake):
                     try:
                         shutil.copytree(src, dst)
                     except OSError, err:
-                        self.log.error("Failed to copy src %s to dst %s: %s" % (src, dst, err))
+                        raise EasyBuildError("Failed to copy src %s to dst %s: %s", src, dst, err)
                     self.log.debug("Copied %s to %s, so GCC can build %s" % (src, dst, d['target_dir']))
                 else:
                     self.log.debug("No need to copy %s to %s, it's already there." % (src, dst))
@@ -200,7 +208,7 @@ class EB_GCC(ConfigureMake):
         (out, ec) = run_cmd("%s %s" % (self.cfg['preconfigopts'], cmd), log_all=True, simple=False)
 
         if ec != 0:
-            self.log.error("Command '%s' exited with exit code != 0 (%s)" % (cmd, ec))
+            raise EasyBuildError("Command '%s' exited with exit code != 0 (%s)", cmd, ec)
 
         # configure scripts tend to simply ignore unrecognized options
         # we should be more strict here, because GCC is very much a moving target
@@ -208,7 +216,7 @@ class EB_GCC(ConfigureMake):
 
         unknown_options = unknown_re.findall(out)
         if unknown_options:
-            self.log.error("Unrecognized options found during configure: %s" % unknown_options)
+            raise EasyBuildError("Unrecognized options found during configure: %s", unknown_options)
 
     def configure_step(self):
         """
@@ -234,6 +242,10 @@ class EB_GCC(ConfigureMake):
         if self.cfg['languages']:
             self.configopts += " --enable-languages=%s" % ','.join(self.cfg['languages'])
 
+        # enable building of libiberty, if desired
+        if self.cfg['withlibiberty']:
+            self.configopts += " --enable-install-libiberty"
+
         # enable link-time-optimization (LTO) support, if desired
         if self.cfg['withlto']:
             self.configopts += " --enable-lto"
@@ -244,12 +256,13 @@ class EB_GCC(ConfigureMake):
         if self.cfg['multilib']:
             glibc_32bit = [
                 "glibc.i686",  # Fedora, RedHat-based
+                "glibc.ppc",   # "" on Power
                 "libc6-dev-i386",  # Debian-based
                 "gcc-c++-32bit",  # OpenSuSE, SLES
             ]
             if not any([check_os_dependency(dep) for dep in glibc_32bit]):
-                msg = "Using multilib requires 32-bit glibc (install one of %s, depending on your OS)" % ', '.join(glibc_32bit)
-                self.log.error(msg)
+                raise EasyBuildError("Using multilib requires 32-bit glibc (install one of %s, depending on your OS)",
+                                     ', '.join(glibc_32bit))
             self.configopts += " --enable-multilib --with-multilib-list=m32,m64"
         else:
             self.configopts += " --disable-multilib"
@@ -281,6 +294,16 @@ class EB_GCC(ConfigureMake):
             self.log.info("Performing regular GCC build...")
             configopts += " --prefix=%(p)s --with-local-prefix=%(p)s" % {'p': self.installdir}
 
+        # prioritize lib over lib{64,32,x32} for all architectures by overriding default MULTILIB_OSDIRNAMES config
+        # only do this when multilib is not enabled
+        if self.cfg['prefer_lib_subdir'] and not self.cfg['multilib']:
+            cfgfile = 'gcc/config/i386/t-linux64'
+            multilib_osdirnames = "MULTILIB_OSDIRNAMES = m64=../lib:../lib64 m32=../lib:../lib32 mx32=../lib:../libx32"
+            self.log.info("Patching MULTILIB_OSDIRNAMES in %s with '%s'", cfgfile, multilib_osdirnames)
+            write_file(cfgfile, multilib_osdirnames, append=True)
+        elif self.cfg['multilib']:
+            self.log.info("Not patching MULTILIB_OSDIRNAMES since use of --enable-multilib is enabled")
+
         # III) create obj dir to build in, and change to it
         #     GCC doesn't like to be built in the source dir
         if self.stagedbuild:
@@ -296,8 +319,6 @@ class EB_GCC(ConfigureMake):
         out, ec = run_cmd("../config.guess", simple=False)
         if ec == 0:
             self.platform_lib = out.rstrip()
-        else:
-            self.platform_lib = get_platform_name(withversion=True)
 
         self.run_configure_cmd(cmd)
 
@@ -347,7 +368,7 @@ class EB_GCC(ConfigureMake):
                     try:
                         os.chdir(libdir)
                     except OSError, err:
-                        self.log.error("Failed to change to %s: %s" % (libdir, err))
+                        raise EasyBuildError("Failed to change to %s: %s", libdir, err)
                     if lib == "gmp":
                         cmd = "./configure --prefix=%s " % stage2prefix
                         cmd += "--with-pic --disable-shared --enable-cxx"
@@ -365,7 +386,7 @@ class EB_GCC(ConfigureMake):
                             else:
                                 cmd += "--disable-watchdog "
                         elif self.cfg['pplwatchdog']:
-                            self.log.error("Enabling PPL watchdog only supported in PPL <= v0.11 .")
+                            raise EasyBuildError("Enabling PPL watchdog only supported in PPL <= v0.11 .")
 
                         # make sure GMP we just built is found
                         cmd += "--with-gmp=%s " % stage2prefix
@@ -389,14 +410,15 @@ class EB_GCC(ConfigureMake):
                                 self.log.debug("Using bundled ISL for CLooG")
                                 cmd += "--with-isl=bundled "
                             else:
-                                self.log.error("Using ISL is only supported in CLooG >= v0.16 (detected v%s)." % self.cloogver)
+                                raise EasyBuildError("Using ISL is only supported in CLooG >= v0.16 (detected v%s).",
+                                                     self.cloogver)
                         else:
                             if self.cloogname == "cloog-ppl" and self.cloogver >= v0_15 and self.cloogver < v0_16:
                                 cmd += "--with-ppl=%s " % stage2prefix
                             else:
                                 errormsg = "PPL only supported with CLooG-PPL v0.15.x (detected v%s)" % self.cloogver
                                 errormsg += "\nNeither using PPL or ISL-based ClooG, I'm out of options..."
-                                self.log.error(errormsg)
+                                raise EasyBuildError(errormsg)
 
                         # make sure GMP is found
                         if self.cloogver >= v0_15 and self.cloogver < v0_16:
@@ -404,9 +426,10 @@ class EB_GCC(ConfigureMake):
                         elif self.cloogver >= v0_16:
                             cmd += "--with-gmp=system --with-gmp-prefix=%s " % stage2prefix
                         else:
-                            self.log.error("Don't know how to specify location of GMP to configure of CLooG v%s." % self.cloogver)
+                            raise EasyBuildError("Don't know how to specify location of GMP to configure of CLooG v%s.",
+                                                 self.cloogver)
                     else:
-                        self.log.error("Don't know how to configure for %s" % lib)
+                        raise EasyBuildError("Don't know how to configure for %s", lib)
 
                     # configure
                     self.run_configure_cmd(cmd)
@@ -434,7 +457,8 @@ class EB_GCC(ConfigureMake):
             self.create_dir("stage3_obj")
 
             # reconfigure for stage 3 build
-            self.log.info("Stage 2 of 3-staged build completed, continuing with stage 2 (with CLooG and/or PPL, ISL support enabled)...")
+            self.log.info("Stage 2 of 3-staged build completed, continuing with stage 2 "
+                          "(with CLooG and/or PPL, ISL support enabled)...")
 
             stage3_info = self.prep_extra_src_dirs("stage3")
             configopts = stage3_info['configopts']
@@ -465,7 +489,7 @@ class EB_GCC(ConfigureMake):
             if self.cfg['withcloog']:
                 configopts += "--with-cloog=%s " % stage2prefix
 
-                if self.cfg['clooguseisl'] and self.cloogver >= LooseVersion("0.16") and self.version < LooseVersion("4.8.0"):
+                if self.cfg['clooguseisl'] and self.cloogver >= LooseVersion("0.16") and LooseVersion(self.version) < LooseVersion("4.8.0"):
                     configopts += "--enable-cloog-backend=isl "
 
             if self.cfg['withisl']:
@@ -500,7 +524,7 @@ class EB_GCC(ConfigureMake):
         if os_type == 'Linux':
             lib_files.extend(["libgcc_s.%s" % sharedlib_ext])
             # libmudflap is replaced by asan (see release notes gcc 4.9.0)
-            if self.version < LooseVersion("4.9.0"):
+            if LooseVersion(self.version) < LooseVersion("4.9.0"):
                 lib_files.extend(["libmudflap.%s" % sharedlib_ext, "libmudflap.a"])
             else:
                 lib_files.extend(["libasan.%s" % sharedlib_ext, "libasan.a"])
@@ -525,7 +549,7 @@ class EB_GCC(ConfigureMake):
             bin_files.append('gfortran')
             lib_files.extend(['libgfortran.%s' % sharedlib_ext, 'libgfortran.a'])
 
-        if 'lto' in self.cfg['languages']:
+        if self.cfg['withlto']:
             libexec_files.extend(['lto1', 'lto-wrapper'])
             if os_type in ['Linux']:
                 libexec_files.append('liblto_plugin.%s' % sharedlib_ext)
