@@ -4,8 +4,8 @@
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -31,14 +31,19 @@ EasyBuild support for building and installing Go, implemented as an easyblock
 import os
 import shutil
 
+from distutils.version import LooseVersion
+
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.filetools import rmtree2
 from easybuild.tools.run import run_cmd
+from easybuild.tools.modules import get_software_root
 
 class EB_Go(ConfigureMake):
     """
     Build Go compiler
     """
+
     def configure_step(self):
         """No dedicated configure step."""
         pass
@@ -56,15 +61,25 @@ class EB_Go(ConfigureMake):
         try:
             os.chdir(srcdir)
         except OSError, err:
-            self.log.error("Failed to move to %s: %s" % (srcdir, err))
+            raise EasyBuildError("Failed to move to %s: %s", srcdir, err)
 
         # $GOROOT_FINAL only specifies the location of the final installation, which gets baked into the binaries
         # the installation itself is *not* done by the all.bash script, that needs to be done manually
-        cmd = "GOROOT_FINAL=%s ./all.bash" % self.installdir
+        # $GOROOT_BOOTSTRAP needs to specify a Go installation directory to build the go toolchain for versions
+        # 1.5 and later.
+        if LooseVersion(self.version) >= LooseVersion('1.5'):
+            go_root = get_software_root('Go')
+            if go_root:
+                cmd = "GOROOT_BOOTSTRAP=%s GOROOT_FINAL=%s ./all.bash" % (go_root, self.installdir)
+            else:
+                raise EasyBuildError("Go is required as a build dependency for installing Go since version 1.5")
+        else:
+            cmd = "GOROOT_FINAL=%s ./all.bash" % self.installdir
+
         run_cmd(cmd, log_all=True, simple=False)
 
         try:
             rmtree2(self.installdir)
             shutil.copytree(self.cfg['start_dir'], self.installdir, symlinks=self.cfg['keepsymlinks'])
         except OSError, err:
-            self.log.error("Failed to copy installation to %s: %s" % (self.installdir, err))
+            raise EasyBuildError("Failed to copy installation to %s: %s", self.installdir, err)
