@@ -1,11 +1,11 @@
 # #
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -31,6 +31,7 @@ EasyBuild support for installing the Intel Math Kernel Library (MKL), implemente
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
 @author: Ward Poelmans (Ghent University)
+@author: Lumir Jasiok (IT4Innovations)
 """
 
 import itertools
@@ -43,9 +44,11 @@ import easybuild.tools.environment as env
 import easybuild.tools.toolchain as toolchain
 from easybuild.easyblocks.generic.intelbase import IntelBase, ACTIVATION_NAME_2012, LICENSE_FILE_NAME_2012
 from easybuild.framework.easyconfig import CUSTOM
-from easybuild.tools.filetools import rmtree2
+from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.filetools import apply_regex_substitutions, rmtree2
 from easybuild.tools.modules import get_software_root
 from easybuild.tools.run import run_cmd
+from easybuild.tools.systemtools import get_shared_lib_ext
 
 
 class EB_imkl(IntelBase):
@@ -68,6 +71,12 @@ class EB_imkl(IntelBase):
         # make sure $MKLROOT isn't set, it's known to cause problems with the installation
         self.cfg.update('unwanted_env_vars', ['MKLROOT'])
 
+    def prepare_step(self):
+        if LooseVersion(self.version) >= LooseVersion('2017.2.174'):
+            super(EB_imkl, self).prepare_step(requires_runtime_license=False)
+        else:
+            super(EB_imkl, self).prepare_step()
+
     def install_step(self):
         """
         Actual installation
@@ -85,7 +94,7 @@ class EB_imkl(IntelBase):
                 'license_file_name': LICENSE_FILE_NAME_2012,
             }
 
-        if LooseVersion(self.version) >= LooseVersion('11.1'):
+        if LooseVersion(self.version) >= LooseVersion('11.1') and self.install_components is None:
             silent_cfg_extras = {
                 'COMPONENTS': 'ALL',
             }
@@ -98,7 +107,7 @@ class EB_imkl(IntelBase):
         """
         if LooseVersion(self.version) >= LooseVersion('10.3'):
             if self.cfg['m32']:
-                self.log.error("32-bit not supported yet for IMKL v%s (>= 10.3)" % self.version)
+                raise EasyBuildError("32-bit not supported yet for IMKL v%s (>= 10.3)", self.version)
             else:
                 retdict = {
                     'PATH': ['bin', 'mkl/bin', 'mkl/bin/intel64', 'composerxe-2011/bin'],
@@ -106,10 +115,11 @@ class EB_imkl(IntelBase):
                     'LIBRARY_PATH': ['lib/intel64', 'mkl/lib/intel64'],
                     'MANPATH': ['man', 'man/en_US'],
                     'CPATH': ['mkl/include', 'mkl/include/fftw'],
-                    'FPATH': ['mkl/include', 'mkl/include/fftw'],
                 }
                 if LooseVersion(self.version) >= LooseVersion('11.0'):
-                    if LooseVersion(self.version) >= LooseVersion('11.1'):
+                    if LooseVersion(self.version) >= LooseVersion('11.3'):
+                        retdict['MIC_LD_LIBRARY_PATH'] = ['lib/intel64_lin_mic', 'mkl/lib/mic'];
+                    elif LooseVersion(self.version) >= LooseVersion('11.1'):
                         retdict['MIC_LD_LIBRARY_PATH'] = ['lib/mic', 'mkl/lib/mic'];
                     else:
                         retdict['MIC_LD_LIBRARY_PATH'] = ['compiler/lib/mic', 'mkl/lib/mic'];
@@ -122,7 +132,6 @@ class EB_imkl(IntelBase):
                     'LIBRARY_PATH': ['lib', 'lib/32'],
                     'MANPATH': ['man', 'share/man', 'man/en_US'],
                     'CPATH': ['include'],
-                    'FPATH': ['include']
                 }
 
             else:
@@ -132,30 +141,28 @@ class EB_imkl(IntelBase):
                     'LIBRARY_PATH': ['lib', 'lib/em64t'],
                     'MANPATH': ['man', 'share/man', 'man/en_US'],
                     'CPATH': ['include'],
-                    'FPATH': ['include'],
                 }
 
     def make_module_extra(self):
         """Overwritten from Application to add extra txt"""
         txt = super(EB_imkl, self).make_module_extra()
-        txt += self.module_generator.prepend_paths(self.license_env_var, [self.license_file], allow_abs=True)
-        if self.cfg['m32']:
-            txt += self.module_generator.prepend_paths('NLSPATH', '$root/idb/32/locale/%l_%t/%N')
-        else:
-            txt += self.module_generator.prepend_paths('NLSPATH', '$root/idb/intel64/locale/%l_%t/%N')
-        txt += self.module_generator.set_environment('MKLROOT', '$root')
+        txt += self.module_generator.set_environment('MKLROOT', os.path.join(self.installdir, 'mkl'))
         return txt
 
     def post_install_step(self):
         """
         Install group libraries and interfaces (if desired).
         """
+        super(EB_imkl, self).post_install_step()
+
+        shlib_ext = get_shared_lib_ext()
+
         # reload the dependencies
         self.load_dependency_modules()
 
         if self.cfg['m32']:
             extra = {
-                'libmkl.so': 'GROUP (-lmkl_intel -lmkl_intel_thread -lmkl_core)',
+                'libmkl.%s' % shlib_ext : 'GROUP (-lmkl_intel -lmkl_intel_thread -lmkl_core)',
                 'libmkl_em64t.a': 'GROUP (libmkl_intel.a libmkl_intel_thread.a libmkl_core.a)',
                 'libmkl_solver.a': 'GROUP (libmkl_solver.a)',
                 'libmkl_scalapack.a': 'GROUP (libmkl_scalapack_core.a)',
@@ -164,7 +171,7 @@ class EB_imkl(IntelBase):
             }
         else:
             extra = {
-                'libmkl.so': 'GROUP (-lmkl_intel_lp64 -lmkl_intel_thread -lmkl_core)',
+                'libmkl.%s' % shlib_ext: 'GROUP (-lmkl_intel_lp64 -lmkl_intel_thread -lmkl_core)',
                 'libmkl_em64t.a': 'GROUP (libmkl_intel_lp64.a libmkl_intel_thread.a libmkl_core.a)',
                 'libmkl_solver.a': 'GROUP (libmkl_solver_lp64.a)',
                 'libmkl_scalapack.a': 'GROUP (libmkl_scalapack_lp64.a)',
@@ -189,7 +196,7 @@ class EB_imkl(IntelBase):
                     f.close()
                     self.log.info("File %s written" % dest)
                 except IOError, err:
-                    self.log.exception("Can't write file %s: %s" % (dest, err))
+                    raise EasyBuildError("Can't write file %s: %s", dest, err)
 
         # build the mkl interfaces, if desired
         if self.cfg['interfaces']:
@@ -219,19 +226,39 @@ class EB_imkl(IntelBase):
                 os.chdir(interfacedir)
                 self.log.info("Changed to interfaces directory %s" % interfacedir)
             except OSError, err:
-                self.log.exception("Can't change to interfaces directory %s" % interfacedir)
+                raise EasyBuildError("Can't change to interfaces directory %s", interfacedir)
 
             compopt = None
-            # determine whether we're using a non-Intel GCC-based toolchain
+            # determine whether we're using a non-Intel GCC-based or PGI-based toolchain
             # can't use toolchain.comp_family, because of dummy toolchain used when installing imkl
             if get_software_root('icc') is None:
-                if get_software_root('GCC'):
+                # check for PGI first, since there's a GCC underneath PGI too...
+                if get_software_root('PGI'):
+                    compopt = 'compiler=pgi'
+                elif get_software_root('GCC'):
                     compopt = 'compiler=gnu'
                 else:
-                    self.log.error("Not using either Intel compilers nor GCC, don't know how to build wrapper libs")
+                    raise EasyBuildError("Not using Intel/GCC/PGI compilers, don't know how to build wrapper libs")
             else:
                 compopt = 'compiler=intel'
 
+            # patch makefiles for cdft wrappers when PGI is used as compiler
+            if get_software_root('PGI'):
+                regex_subs = [
+                    # pgi should be considered as a valid compiler
+                    ("intel gnu", "intel gnu pgi"),
+                    # transform 'gnu' case to 'pgi' case
+                    (r"ifeq \(\$\(compiler\),gnu\)", "ifeq ($(compiler),pgi)"),
+                    ('=gcc', '=pgcc'),
+                    # correct flag to use C99 standard
+                    ('-std=c99', '-c99'),
+                    # -Wall and -Werror are not valid options for pgcc, no close equivalent
+                    ('-Wall', ''),
+                    ('-Werror', ''),
+                ]
+                for lib in cdftlibs:
+                    apply_regex_substitutions(os.path.join(interfacedir, lib, 'makefile'), regex_subs)
+
             for lib in fftw2libs + fftw3libs + cdftlibs:
                 buildopts = [compopt]
                 if lib in fftw3libs:
@@ -293,12 +320,12 @@ class EB_imkl(IntelBase):
                         os.chdir(intdir)
                         self.log.info("Changed to interface %s directory %s" % (lib, intdir))
                     except OSError, err:
-                        self.log.error("Can't change to interface %s directory %s: %s" % (lib, intdir, err))
+                        raise EasyBuildError("Can't change to interface %s directory %s: %s", lib, intdir, err)
 
                     fullcmd = "%s %s" % (cmd, ' '.join(buildopts + extraopts))
                     res = run_cmd(fullcmd, log_all=True, simple=True)
                     if not res:
-                        self.log.error("Building %s (flags: %s, fullcmd: %s) failed" % (lib, flags, fullcmd))
+                        raise EasyBuildError("Building %s (flags: %s, fullcmd: %s) failed", lib, flags, fullcmd)
 
                     for fn in os.listdir(tmpbuild):
                         src = os.path.join(tmpbuild, fn)
@@ -312,26 +339,32 @@ class EB_imkl(IntelBase):
                                 shutil.move(src, dest)
                                 self.log.info("Moved %s to %s" % (src, dest))
                         except OSError, err:
-                            self.log.error("Failed to move %s to %s: %s" % (src, dest, err))
+                            raise EasyBuildError("Failed to move %s to %s: %s", src, dest, err)
 
                     rmtree2(tmpbuild)
 
     def sanity_check_step(self):
         """Custom sanity check paths for Intel MKL."""
+        shlib_ext = get_shared_lib_ext()
+
         mklfiles = None
         mkldirs = None
         ver = LooseVersion(self.version)
-        libs = ["libmkl_core.so", "libmkl_gnu_thread.so", "libmkl_intel_thread.so", "libmkl_sequential.so"]
-        extralibs = ["libmkl_blacs_intelmpi_%(suff)s.so", "libmkl_scalapack_%(suff)s.so"]
-
-        compsuff = '_intel'
-        if get_software_root('icc') is None:
-            if get_software_root('GCC'):
-                compsuff = '_gnu'
-            else:
-                self.log.error("Not using Intel compilers or GCC, don't know compiler suffix for FFTW libraries.")
+        libs = ['libmkl_core.%s' % shlib_ext, 'libmkl_gnu_thread.%s' % shlib_ext,
+                'libmkl_intel_thread.%s' % shlib_ext, 'libmkl_sequential.%s' % shlib_ext]
+        extralibs = ['libmkl_blacs_intelmpi_%(suff)s.' + shlib_ext, 'libmkl_scalapack_%(suff)s.' + shlib_ext]
 
         if self.cfg['interfaces']:
+            compsuff = '_intel'
+            if get_software_root('icc') is None:
+                # check for PGI first, since there's a GCC underneath PGI too...
+                if get_software_root('PGI'):
+                    compsuff = '_pgi'
+                elif get_software_root('GCC'):
+                    compsuff = '_gnu'
+                else:
+                    raise EasyBuildError("Not using Intel/GCC/PGI, don't know compiler suffix for FFTW libraries.")
+
             precs = ['_double', '_single']
             if ver < LooseVersion('11'):
                 # no precision suffix in libfftw2 libs before imkl v11
@@ -356,27 +389,32 @@ class EB_imkl(IntelBase):
 
         if ver >= LooseVersion('10.3'):
             if self.cfg['m32']:
-                self.log.error("Sanity check for 32-bit not implemented yet for IMKL v%s (>= 10.3)" % self.version)
+                raise EasyBuildError("Sanity check for 32-bit not implemented yet for IMKL v%s (>= 10.3)", self.version)
             else:
-                mkldirs = ["bin", "mkl/bin", "mkl/bin/intel64", "mkl/lib/intel64", "mkl/include"]
+                mkldirs = ['bin', 'mkl/bin', 'mkl/lib/intel64', 'mkl/include']
+                if ver < LooseVersion('11.3'):
+                    mkldirs.append('mkl/bin/intel64')
                 libs += [lib % {'suff': suff} for lib in extralibs for suff in ['lp64', 'ilp64']]
-                mklfiles = ["mkl/lib/intel64/libmkl.so", "mkl/include/mkl.h"] + \
-                           ["mkl/lib/intel64/%s" % lib for lib in libs]
+                mklfiles = ['mkl/lib/intel64/libmkl.%s' % shlib_ext, 'mkl/include/mkl.h'] + \
+                           ['mkl/lib/intel64/%s' % lib for lib in libs]
                 if ver >= LooseVersion('10.3.4') and ver < LooseVersion('11.1'):
-                    mkldirs += ["compiler/lib/intel64"]
+                    mkldirs += ['compiler/lib/intel64']
                 else:
-                    mkldirs += ["lib/intel64"]
+                    if ver >= LooseVersion('2017.0.0'):
+                        mkldirs += ['lib/intel64_lin']
+                    else:
+                        mkldirs += ['lib/intel64']
 
         else:
             if self.cfg['m32']:
-                mklfiles = ["lib/32/libmkl.so", "include/mkl.h"] + \
-                           ["lib/32/%s" % lib for lib in libs]
-                mkldirs = ["lib/32", "include/32", "interfaces"]
+                mklfiles = ['lib/32/libmkl.%s' % shlib_ext, 'include/mkl.h'] + \
+                           ['lib/32/%s' % lib for lib in libs]
+                mkldirs = ['lib/32', 'include/32', 'interfaces']
             else:
                 libs += [lib % {'suff': suff} for lib in extralibs for suff in ['lp64', 'ilp64']]
-                mklfiles = ["lib/em64t/libmkl.so", "include/mkl.h"] + \
-                           ["lib/em64t/%s" % lib for lib in libs]
-                mkldirs = ["lib/em64t", "include/em64t", "interfaces"]
+                mklfiles = ['lib/em64t/libmkl.%s' % shlib_ext, 'include/mkl.h'] + \
+                           ['lib/em64t/%s' % lib for lib in libs]
+                mkldirs = ['lib/em64t', 'include/em64t', 'interfaces']
 
         custom_paths = {
             'files': mklfiles,
