@@ -4,8 +4,8 @@
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -27,6 +27,7 @@ EasyBuild support for installing Intel Inspector, implemented as an easyblock
 
 @author: Kenneth Hoste (Ghent University)
 """
+import os
 from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.intelbase import IntelBase, ACTIVATION_NAME_2012, LICENSE_FILE_NAME_2012
@@ -36,6 +37,22 @@ class EB_Inspector(IntelBase):
     """
     Support for installing Intel Inspector
     """
+
+    def __init__(self, *args, **kwargs):
+        """Easyblock constructor; define class variables."""
+        super(EB_Inspector, self).__init__(*args, **kwargs)
+
+        # recent versions of Inspector are installed to a subdirectory
+        self.subdir = ''
+        if LooseVersion(self.version) >= LooseVersion('2013_update7') and LooseVersion(self.version) < LooseVersion('2017'):
+            self.subdir = 'inspector_xe'
+        elif LooseVersion(self.version) >= LooseVersion('2017'):
+            self.subdir = 'inspector'
+
+    def make_installdir(self):
+        """Do not create installation directory, install script handles that already."""
+        super(EB_Inspector, self).make_installdir(dontcreate=True)
+
     def install_step(self):
         """
         Actual installation
@@ -61,46 +78,37 @@ class EB_Inspector(IntelBase):
 
         if self.cfg['m32']:
             guesses.update({
-                'PATH': ['bin32'],
-                'LD_LIBRARY_PATH': ['lib32'],
-                'LIBRARY_PATH': ['lib32'],
+                'PATH': [os.path.join(self.subdir, 'bin32')],
+                'LD_LIBRARY_PATH': [os.path.join(self.subdir, 'lib32')],
+                'LIBRARY_PATH': [os.path.join(self.subdir, 'lib32')],
             })
         else:
             guesses.update({
-                'PATH': ['bin64'],
-                'LD_LIBRARY_PATH': ['lib64'],
-                'LIBRARY_PATH': ['lib64'],
+                'PATH': [os.path.join(self.subdir, 'bin64')],
+                'LD_LIBRARY_PATH': [os.path.join(self.subdir, 'lib64')],
+                'LIBRARY_PATH': [os.path.join(self.subdir, 'lib64')],
             })
 
         guesses.update({
-            'CPATH': ['include'],
-            'FPATH': ['include'],
+            'CPATH': [os.path.join(self.subdir, 'include')],
+            'MANPATH': [os.path.join(self.subdir, 'man')],
         })
 
         return guesses
 
-    def make_module_extra(self):
-        """Custom variable definitions in module file."""
-        
-        txt = super(EB_Inspector, self).make_module_extra()
-        txt += self.module_generator.prepend_paths(self.license_env_var, self.license_file, allow_abs=True)
-
-        return txt
-
     def sanity_check_step(self):
         """Custom sanity check paths for Intel Inspector."""
 
         binaries = ['inspxe-cl', 'inspxe-feedback', 'inspxe-gui', 'inspxe-runmc', 'inspxe-runtc']
         if self.cfg['m32']:
-            files = ["bin32/%s" % x for x in binaries]
-            dirs = ["lib32", "include"]
+            files = [os.path.join('bin32', b) for b in binaries]
+            dirs = ['lib32', 'include']
         else:
-            files = ["bin64/%s" % x for x in binaries]
-            dirs = ["lib64", "include"]
+            files = [os.path.join('bin64', b) for b in binaries]
+            dirs = ['lib64', 'include']
 
         custom_paths = {
-                        'files': files,
-                        'dirs': dirs,
-                       }
-
+            'files': [os.path.join(self.subdir, f) for f in files],
+            'dirs': [os.path.join(self.subdir, d) for d in dirs],
+        }
         super(EB_Inspector, self).sanity_check_step(custom_paths=custom_paths)
