@@ -4,8 +4,8 @@
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -31,6 +31,7 @@ import os
 
 from easybuild.easyblocks.generic.binary import Binary
 from easybuild.framework.easyconfig import CUSTOM
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.run import run_cmd_qa
 
 
@@ -49,7 +50,7 @@ class EB_Mathematica(Binary):
         """No configuration for Mathematica."""
         # ensure a license server is specified
         if self.cfg['license_server'] is None:
-            self.log.error("No license server specified.")
+            raise EasyBuildError("No license server specified.")
 
     def build_step(self):
         """No build step for Mathematica."""
@@ -72,7 +73,7 @@ class EB_Mathematica(Binary):
         no_qa = [
             "Now installing.*\n\n.*\[.*\].*",
         ]
-        run_cmd_qa(cmd, qa, no_qa=no_qa, log_all=True, simple=True)
+        run_cmd_qa(cmd, qa, no_qa=no_qa, log_all=True, simple=True, maxhits=200)
 
         # add license server configuration file
         # some relevant documentation at http://reference.wolfram.com/mathematica/tutorial/ConfigurationFiles.html
@@ -87,7 +88,7 @@ class EB_Mathematica(Binary):
             f.close()
             self.log.info("Updated license file %s: %s" % (mathpass_path, mathpass_txt))
         except IOError, err:
-            self.log.error("Failed to update %s with license server info: %s" % (mathpass_path, err))
+            raise EasyBuildError("Failed to update %s with license server info: %s", mathpass_path, err)
 
         # restore $DISPLAY if required
         if orig_display is not None:
