@@ -31,6 +31,7 @@ import os
 
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.run import run_cmd_qa
 
 
@@ -49,7 +50,7 @@ class EB_Modeller(EasyBlock):
         """Interactive install of Modeller."""
     
         if self.cfg['key'] is None: 
-            self.log.error("Easyconfig parameter 'key' is not defined")
+            raise EasyBuildError("Easyconfig parameter 'key' is not defined")
 
         cmd = "%s/Install" % self.cfg['start_dir']
 
@@ -80,20 +81,23 @@ class EB_Modeller(EasyBlock):
         """Custom guesses for environment variables (PYTHONPATH, LD_LIBRARY_PATH) for modeller."""
         guesses = super(EB_Modeller, self).make_module_req_guess()
 
-        libdirs = os.listdir(os.path.join(self.installdir, 'lib'))
-        if len(libdirs) == 1:
-            libdir = libdirs[0]
-        else:
-            self.log.error("Failed to isolate a single libdir from list of 'lib' subdirectories: %s" % libdirs)
+        libspath = os.path.join(self.installdir, 'lib')
+        if os.path.exists(libspath):
+            libdirs = os.listdir(libspath)
+            if len(libdirs) == 1:
+                libdir = libdirs[0]
+            else:
+                raise EasyBuildError("Failed to isolate a single libdir from list of 'lib' subdirectories: %s", libdirs)
 
-        py2libdirs = [d for d in os.listdir(os.path.join(self.installdir, 'lib', libdir)) if d.startswith('python2')]
-        if len(py2libdirs) >= 1:
-            py2libdir = py2libdirs[-1]
-        else:
-            self.log.error("Failed to isolate latest Python lib dir from list %s" % py2libdirs)
+            py2libdirs = [d for d in os.listdir(os.path.join(libspath, libdir)) if d.startswith('python2')]
+            if len(py2libdirs) >= 1:
+                py2libdir = py2libdirs[-1]
+            else:
+                raise EasyBuildError("Failed to isolate latest Python lib dir from list %s", py2libdirs)
+
+            guesses.update({
+                'PYTHONPATH': [os.path.join('lib', libdir, py2libdir), "modlib"],
+                'LD_LIBRARY_PATH': [os.path.join('lib', libdir)],
+            })
 
-        guesses.update({
-            'PYTHONPATH': [os.path.join('lib', libdir, py2libdir), "modlib"],
-            'LD_LIBRARY_PATH': [os.path.join('lib', libdir)],
-        })
         return guesses
