@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -31,7 +31,8 @@ EasyBuild support for building and installing Python, implemented as an easybloc
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
 """
-
+import copy
+import glob
 import os
 import re
 import fileinput
@@ -40,8 +41,10 @@ from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.tools.build_log import EasyBuildError
-from easybuild.tools.modules import get_software_libdir, get_software_root
+from easybuild.tools.modules import get_software_libdir, get_software_libdir, get_software_root, get_software_version
+from easybuild.tools.filetools import remove_file, symlink
 from easybuild.tools.run import run_cmd
+from easybuild.tools.systemtools import get_shared_lib_ext
 
 
 EXTS_FILTER_PYTHON_PACKAGES = ('python -c "import %(ext_name)s"', "")
@@ -67,10 +70,26 @@ class EB_Python(ConfigureMake):
         self.cfg['exts_defaultclass'] = "PythonPackage"
         self.cfg['exts_filter'] = EXTS_FILTER_PYTHON_PACKAGES
 
+        # don't pass down any build/install options that may have been specified
+        # 'make' options do not make sense for when building/installing Python libraries (usually via 'python setup.py')
+        msg = "Unsetting '%s' easyconfig parameter before building/installing extensions: %s"
+        for param in ['buildopts', 'installopts']:
+            if self.cfg[param]:
+                self.log.debug(msg, param, self.cfg[param])
+            self.cfg[param] = ''
+
     def configure_step(self):
         """Set extra configure options."""
         self.cfg.update('configopts', "--with-threads --enable-shared")
 
+        # Need to be careful to match the unicode settings to the underlying python
+        if sys.maxunicode == 1114111:
+            self.cfg.update('configopts', "--enable-unicode=ucs4")
+        elif sys.maxunicode == 65535:
+            self.cfg.update('configopts', "--enable-unicode=ucs2")
+        else:
+            raise EasyBuildError("Unknown maxunicode value for your python: %d" % sys.maxunicode)
+
         modules_setup_dist = os.path.join(self.cfg['start_dir'], 'Modules', 'Setup.dist')
 
         libreadline = get_software_root('libreadline')
@@ -86,7 +105,7 @@ class EB_Python(ConfigureMake):
                     line = re.sub(r"^#readline readline.c.*", readline, line)
                     sys.stdout.write(line)
             else:
-                self.log.error("Both libreadline and ncurses are required to ensure readline support")
+                raise EasyBuildError("Both libreadline and ncurses are required to ensure readline support")
 
         openssl = get_software_root('OpenSSL')
         if openssl:
@@ -96,6 +115,26 @@ class EB_Python(ConfigureMake):
                 line = re.sub(r"^#(\s*-L\$\(SSL\)/lib )", r"\1 -L$(SSL)/lib64 ", line)
                 sys.stdout.write(line)
 
+        tcl = get_software_root('Tcl')
+        tk = get_software_root('Tk')
+        if tcl and tk:
+            tclver = get_software_version('Tcl')
+            tkver = get_software_version('Tk')
+            tcltk_maj_min_ver = '.'.join(tclver.split('.')[:2])
+            if tcltk_maj_min_ver != '.'.join(tkver.split('.')[:2]):
+                raise EasyBuildError("Tcl and Tk major/minor versions don't match: %s vs %s", tclver, tkver)
+
+            self.cfg.update('configopts', "--with-tcltk-includes='-I%s/include -I%s/include'" % (tcl, tk))
+
+            tcl_libdir = os.path.join(tcl, get_software_libdir('Tcl'))
+            tk_libdir = os.path.join(tk, get_software_libdir('Tk'))
+            tcltk_libs = "-L%(tcl_libdir)s -L%(tk_libdir)s -ltcl%(maj_min_ver)s -ltk%(maj_min_ver)s" % {
+                'tcl_libdir': tcl_libdir,
+                'tk_libdir': tk_libdir,
+                'maj_min_ver': tcltk_maj_min_ver,
+            }
+            self.cfg.update('configopts', "--with-tcltk-libs='%s'" % tcltk_libs)
+
         super(EB_Python, self).configure_step()
 
     def install_step(self):
@@ -104,22 +143,19 @@ class EB_Python(ConfigureMake):
 
         python_binary_path = os.path.join(self.installdir, 'bin', 'python')
         if not os.path.isfile(python_binary_path):
-            pythonver = '.'.join(self.version.split('.')[0:2])
-            srcbin = "%s%s" % (python_binary_path, pythonver)
-            try:
-                os.symlink(srcbin, python_binary_path)
-            except OSError, err:
-                self.log.error("Failed to symlink %s to %s: %s" % err)
+            pyver = '.'.join(self.version.split('.')[:2])
+            symlink(python_binary_path + pyver, python_binary_path)
 
     def sanity_check_step(self):
         """Custom sanity check for Python."""
 
-        pyver = "python%s" % '.'.join(self.version.split('.')[0:2])
+        pyver = 'python' + '.'.join(self.version.split('.')[:2])
+        shlib_ext = get_shared_lib_ext()
 
         try:
             fake_mod_data = self.load_fake_module()
         except EasyBuildError, err:
-            self.log.error("Loading fake module failed: %s" % err)
+            raise EasyBuildError("Loading fake module failed: %s", err)
 
         abiflags = ''
         if LooseVersion(self.version) >= LooseVersion("3"):
@@ -127,23 +163,39 @@ class EB_Python(ConfigureMake):
             cmd = 'python -c "import sysconfig; print(sysconfig.get_config_var(\'abiflags\'));"'
             (abiflags, _) = run_cmd(cmd, log_all=True, simple=False)
             if not abiflags:
-                self.log.error("Failed to determine abiflags: %s" % abiflags)
+                raise EasyBuildError("Failed to determine abiflags: %s", abiflags)
             else:
                 abiflags = abiflags.strip()
 
         custom_paths = {
-            'files': ["bin/%s" % pyver, "lib/lib%s%s.so" % (pyver, abiflags)],
-            'dirs': ["include/%s%s" % (pyver, abiflags), "lib/%s" % pyver],
+            'files': [os.path.join('bin', pyver), os.path.join('lib', 'lib' + pyver + abiflags + '.' + shlib_ext)],
+            'dirs': [os.path.join('include', pyver + abiflags), os.path.join('lib', pyver)],
         }
 
         # cleanup
         self.clean_up_fake_module(fake_mod_data)
 
         custom_commands = [
-            ('python', '--version'),
-            ('python', '-c "import _ctypes"'),  # make sure that foreign function interface (libffi) works
-            ('python', '-c "import _ssl"'),  # make sure SSL support is enabled one way or another
-            ('python', '-c "import readline"'),  # make sure readline support was built correctly
+            "python --version",
+            "python -c 'import _ctypes'",  # make sure that foreign function interface (libffi) works
+            "python -c 'import _ssl'",  # make sure SSL support is enabled one way or another
+            "python -c 'import readline'",  # make sure readline support was built correctly
         ]
 
+        if get_software_root('Tk'):
+            # also check whether importing tkinter module works, name is different for Python v2.x and v3.x
+            if LooseVersion(self.version) >= LooseVersion('3'):
+                tkinter = 'tkinter'
+            else:
+                tkinter = 'Tkinter'
+            custom_commands.append("python -c 'import %s'" % tkinter)
+
+            # check whether _tkinter*.so is found, exact filename doesn't matter
+            tkinter_so = os.path.join(self.installdir, 'lib', pyver, 'lib-dynload', '_tkinter*.' + shlib_ext)
+            tkinter_so_hits = glob.glob(tkinter_so)
+            if len(tkinter_so_hits) == 1:
+                self.log.info("Found exactly one _tkinter*.so: %s", tkinter_so_hits[0])
+            else:
+                raise EasyBuildError("Expected to find exactly one _tkinter*.so: %s", tkinter_so_hits)
+
         super(EB_Python, self).sanity_check_step(custom_paths=custom_paths, custom_commands=custom_commands)
