@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -37,6 +37,7 @@ import shutil
 import tempfile
 
 from easybuild.easyblocks.generic.pythonpackage import PythonPackage
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.filetools import extract_file, rmtree2
 from easybuild.tools.modules import get_software_root
 from easybuild.tools.run import run_cmd
@@ -54,7 +55,8 @@ class EB_python_minus_meep(PythonPackage):
         deps = ["Meep", "Python"]
         for dep in deps:
             if not get_software_root(dep):
-                self.log.error("Module for %s not loaded." % dep)
+                raise EasyBuildError("Module for %s not loaded.", dep)
+        super(EB_python_minus_meep, self).configure_step()
 
     def build_step(self):
         """Build python-meep using available make/make-mpi script."""
@@ -88,9 +90,9 @@ class EB_python_minus_meep(PythonPackage):
                                   "%s-%s.*.tar.gz" % (self.name, shortver))
         matches = glob.glob(fn_pattern)
         if not matches:
-            self.log.error("No tarball found at %s" % fn_pattern)
+            raise EasyBuildError("No tarball found at %s", fn_pattern)
         elif len(matches) > 1:
-            self.log.error("Multiple matches found for tarball: %s" % matches)
+            raise EasyBuildError("Multiple matches found for tarball: %s", matches)
         else:
             tarball = matches[0]
             self.log.info("Tarball found at %s" % tarball)
@@ -99,14 +101,14 @@ class EB_python_minus_meep(PythonPackage):
         tmpdir = tempfile.mkdtemp()
         srcdir = extract_file(tarball, tmpdir)
         if not srcdir:
-            self.log.error("Unpacking tarball %s failed?" % tarball)
+            raise EasyBuildError("Unpacking tarball %s failed?", tarball)
 
         # locate site-packages dir to copy by diving into unpacked tarball
         src = srcdir
         while len(os.listdir(src)) == 1:
             src = os.path.join(src, os.listdir(src)[0])
         if not os.path.basename(src) =='site-packages':
-            self.log.error("Expected to find a site-packages path, but found something else: %s" % src)
+            raise EasyBuildError("Expected to find a site-packages path, but found something else: %s", src)
 
         # copy contents of site-packages dir
         dest = os.path.join(self.installdir, 'site-packages')
@@ -115,7 +117,7 @@ class EB_python_minus_meep(PythonPackage):
             rmtree2(tmpdir)
             os.chdir(self.installdir)
         except OSError, err:
-            self.log.exception("Failed to copy directory %s to %s: %s" % (src, dest, err))
+            raise EasyBuildError("Failed to copy directory %s to %s: %s", src, dest, err)
 
     def sanity_check_step(self):
 
@@ -134,11 +136,11 @@ class EB_python_minus_meep(PythonPackage):
         txt = super(EB_python_minus_meep, self).make_module_extra()
 
         meep = get_software_root('Meep')
-
-        txt += "setenv\tMEEP_INCLUDE\t\t%s/include\n" % meep
-        txt += "setenv\tMEEP_LIB\t\t%s/lib\n" % meep
+        if meep is not None:
+            txt += self.module_generator.set_environment('MEEP_INCLUDE', os.path.join(meep, 'include'))
+            txt += self.module_generator.set_environment('MEEP_LIB', os.path.join(meep, 'lib'))
 
         for var in ["PYTHONMEEPPATH", "PYTHONMEEP_INCLUDE", "PYTHONPATH"]:
-            txt += "setenv\t%s\t\t$root/site-packages\n" % var
+            txt += self.module_generator.set_environment(var, os.path.join(self.installdir, 'site-packages'))
 
         return txt
