@@ -1,11 +1,11 @@
 ##
-# Copyright 2012-2013 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -28,9 +28,12 @@ EasyBuild support for building and installing R, implemented as an easyblock
 @author: Jens Timmerman (Ghent University)
 """
 import os
+from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.tools import environment
+from easybuild.tools.modules import get_software_root
+from easybuild.tools.systemtools import get_shared_lib_ext
 
 
 EXTS_FILTER_R_PACKAGES = ("R -q --no-save", "library(%(ext_name)s)")
@@ -54,7 +57,15 @@ class EB_R(ConfigureMake):
     def configure_step(self):
         """Configuration step, we set FC, F77 is already set by EasyBuild to the right compiler,
         FC is used for Fortan90"""
-        environment.setvar("FC", self.toolchain.get_variable('F90'))
+        environment.setvar('FC', self.toolchain.get_variable('F90'))
+
+        # make sure correct config script is used for Tcl/Tk
+        for dep in ['Tcl', 'Tk']:
+            root = get_software_root(dep)
+            if root:
+                dep_config = os.path.join(root, 'lib', '%sConfig.sh' % dep.lower())
+                self.cfg.update('configopts', '-with-%s-config=%s' % (dep.lower(), dep_config))
+
         ConfigureMake.configure_step(self)
     
     def make_module_req_guess(self):
@@ -73,12 +84,16 @@ class EB_R(ConfigureMake):
 
     def sanity_check_step(self):
         """Custom sanity check for R."""
+        shlib_ext = get_shared_lib_ext()
 
         libfiles = [os.path.join('include', x) for x in ['Rconfig.h', 'Rdefines.h', 'Rembedded.h',
                                                          'R.h', 'Rinterface.h', 'Rinternals.h',
                                                          'Rmath.h', 'Rversion.h', 'S.h']]
-        libfiles += [os.path.join('modules', x) for x in ['internet.so', 'lapack.so', 'vfonts.so']]
-        libfiles += ['lib/libR.so']
+        modfiles = ['internet.%s' % shlib_ext, 'lapack.%s' % shlib_ext]
+        if LooseVersion(self.version) < LooseVersion('3.2'):
+            modfiles.append('vfonts.%s' % shlib_ext)
+        libfiles += [os.path.join('modules', x) for x in modfiles]
+        libfiles += ['lib/libR.%s' % shlib_ext]
 
         custom_paths = {
             'files': ['bin/%s' % x for x in ['R', 'Rscript']] +
