@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -50,9 +50,10 @@ class EB_ROOT(ConfigureMake):
 
         self.cfg.update('configopts', "--etcdir=%s/etc/root " % self.installdir)
 
-        cmd = "./configure %s --prefix=%s %s" % (self.cfg['arch'],
-                                                 self.installdir,
-                                                 self.cfg['configopts'])
+        cmd = "%s ./configure %s --prefix=%s %s" % (self.cfg['preconfigopts'],
+                                                    self.cfg['arch'],
+                                                    self.installdir,
+                                                    self.cfg['configopts'])
 
         run_cmd(cmd, log_all=True, log_ok=True, simple=True)
 
@@ -60,7 +61,7 @@ class EB_ROOT(ConfigureMake):
         """Custom extra module file entries for ROOT."""
         txt = super(EB_ROOT, self).make_module_extra()
 
-        txt += self.module_generator.set_environment('ROOTSYS', '$root')
+        txt += self.module_generator.set_environment('ROOTSYS', self.installdir)
         txt += self.module_generator.prepend_paths('CPATH',['include/root'])
         txt += self.module_generator.prepend_paths('LD_LIBRARY_PATH',['lib/root'])
         txt += self.module_generator.prepend_paths('PYTHONPATH', ['lib/root', 'lib/root/python'])
