@@ -1,11 +1,11 @@
 ##
-# Copyright 2012-2013 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -30,7 +30,9 @@ EasyBuild support for UFC, implemented as an easyblock
 from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.cmakepythonpackage import CMakePythonPackage
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.modules import get_software_root, get_software_version
+from easybuild.tools.systemtools import get_shared_lib_ext
 
 
 class EB_UFC(CMakePythonPackage):
@@ -44,6 +46,7 @@ class EB_UFC(CMakePythonPackage):
 
     def configure_step(self):
         """Set some extra environment variables before configuring."""
+        shlib_ext = get_shared_lib_ext()
 
         # make sure that required dependencies are loaded
         deps = ['Boost', 'Python', 'SWIG']
@@ -51,7 +54,7 @@ class EB_UFC(CMakePythonPackage):
         for dep in deps:
             deproot = get_software_root(dep)
             if not deproot:
-                self.log.error("%s module not loaded?" % dep)
+                raise EasyBuildError("%s module not loaded?", dep)
             else:
                 depsdict.update({dep:deproot})
 
@@ -59,8 +62,8 @@ class EB_UFC(CMakePythonPackage):
         # which causes problems with e.g. DOLFIN if UFC was built with it
         # fixed in 2.0.7? see https://bugs.launchpad.net/dolfin/+bug/996398
         if LooseVersion(get_software_version('SWIG')) > '2.0.4':
-            self.log.error("Using bad version of SWIG, expecting swig <= 2.0.4." \
-                           " See https://bugs.launchpad.net/dolfin/+bug/996398")
+            raise EasyBuildError("Using bad version of SWIG, expecting swig <= 2.0.4. "
+                                 "See https://bugs.launchpad.net/dolfin/+bug/996398")
 
         self.pyver = ".".join(get_software_version('Python').split(".")[:-1])
 
@@ -70,19 +73,22 @@ class EB_UFC(CMakePythonPackage):
 
         self.cfg.update('configopts', '-DUFC_ENABLE_PYTHON:BOOL=ON')
         self.cfg.update('configopts', '-DSWIG_FOUND:BOOL=ON')
-        self.cfg.update('configopts', '-DPYTHON_LIBRARY=%s/lib/libpython%s.so' % (depsdict['Python'],
-                                                                                 self.pyver))
-        self.cfg.update('configopts', '-DPYTHON_INCLUDE_PATH=%s/include/python%s' % (depsdict['Python'],
-                                                                                    self.pyver))
+        python = depsdict['Python']
+        self.cfg.update('configopts', '-DPYTHON_LIBRARY=%s/lib/libpython%s.%s' % (python, self.pyver, shlib_ext))
+        self.cfg.update('configopts', '-DPYTHON_INCLUDE_PATH=%s/include/python%s' % (python, self.pyver))
 
         super(EB_UFC, self).configure_step()
 
+    def test_step(self):
+        """No test suite available for UFC."""
+        # PythonPackage defines 'runtest' as 'True' by default, but ConfigureMake.test_step expects string value
+        # no test suite available anyway for UFC, so just pass through
+        pass
+
     def sanity_check_step(self):
         """Custom sanity check for UFC."""
-
         custom_paths = {
-                        'files': ['include/ufc.h'],
-                        'dirs': ['lib/python%s/site-packages/%s/' % (self.pyver, x) for x in ['ufc', 'ufc_utils']],
-                       }
-
+            'files': ['include/ufc.h'],
+            'dirs': ['lib/python%s/site-packages/%s/' % (self.pyver, x) for x in ['ufc', 'ufc_utils']],
+        }
         super(EB_UFC, self).sanity_check_step(custom_paths=custom_paths)
