@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -30,6 +30,8 @@ EasyBuild support for building and installing WIEN2k, implemented as an easybloc
 @author: Kenneth Hoste (Ghent University)
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
+@author: Michael Sluydts (Ghent University)
+
 """
 import fileinput
 import os
@@ -43,8 +45,9 @@ import easybuild.tools.environment as env
 import easybuild.tools.toolchain as toolchain
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM
-from easybuild.tools.filetools import extract_file, rmtree2
-from easybuild.tools.modules import get_software_version
+from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.filetools import extract_file, mkdir, read_file, rmtree2, write_file
+from easybuild.tools.modules import get_software_root, get_software_version
 from easybuild.tools.run import run_cmd, run_cmd_qa
 
 
@@ -54,7 +57,6 @@ class EB_WIEN2k(EasyBlock):
     def __init__(self,*args,**kwargs):
         """Enable building in install dir."""
         super(EB_WIEN2k, self).__init__(*args, **kwargs)
-
         self.build_in_installdir = True
 
     @staticmethod
@@ -65,8 +67,12 @@ class EB_WIEN2k(EasyBlock):
         extra_vars = {
             'runtest': [True, "Run WIEN2k tests", CUSTOM],
             'testdata': [testdata_urls, "test data URL for WIEN2k benchmark test", CUSTOM],
-            'wien_mpirun': [None, "MPI wrapper comand to use", CUSTOM],
+            'wien_mpirun': [None, "MPI wrapper command to use", CUSTOM],
             'remote': [None, "Remote command to use (e.g. pbsssh, ...)", CUSTOM],
+            'use_remote': [True, "Whether to remotely login to initiate the k-point parallellization calls", CUSTOM],
+            'mpi_remote': [False, "Whether to initiate MPI calls locally or remotely", CUSTOM],
+            'wien_granularity': [True, "Granularity for parallel execution (see manual)", CUSTOM],
+            'taskset': [None, "Specifies an optional command for binding a process to a specific core", CUSTOM],
         }
         return EasyBlock.extra_options(extra_vars)
 
@@ -105,7 +111,7 @@ class EB_WIEN2k(EasyBlock):
             comp_answer = 'V'  # Linux (gfortran compiler + gotolib)
 
         else:
-            self.log.error("Failed to determine toolchain-dependent answers.")
+            raise EasyBuildError("Failed to determine toolchain-dependent answers.")
 
         # libraries
         rlibs = "%s %s" % (os.getenv('LIBLAPACK_MT'), self.toolchain.get_flag('openmp'))
@@ -148,83 +154,102 @@ class EB_WIEN2k(EasyBlock):
         env.setvar('bin', os.getcwd())
 
         dc = {
-              'COMPILERC': os.getenv('CC'),
-              'COMPILER': os.getenv('F90'),
-              'COMPILERP': os.getenv('MPIF90'),
-             }
+            'COMPILERC': os.getenv('CC'),
+            'COMPILER': os.getenv('F90'),
+            'COMPILERP': os.getenv('MPIF90'),
+        }
 
-        for (k,v) in dc.items():
-            f = open(k,"w")
-            f.write(v)
-            f.close()
+        for (k, v) in dc.items():
+            write_file(k, v)
 
         # configure with patched configure script
         self.log.debug('%s part I (configure)' % self.cfgscript)
 
         cmd = "./%s" % self.cfgscript
         qanda = {
-                 'Press RETURN to continue': '',
+             'Press RETURN to continue': '',
+             'Your compiler:': '',
+             'Hit Enter to continue': '',
+             'Remote shell (default is ssh) =': '',
+             'and you need to know details about your installed  mpi ..) (y/n)': 'y',
+             'Q to quit Selection:': 'Q',
+             'A Compile all programs (suggested) Q Quit Selection:': 'Q',
+             ' Please enter the full path of the perl program: ': '',
+             'continue or stop (c/s)': 'c',
+             '(like taskset -c). Enter N / your_specific_command:': 'N',
+        }
+        if LooseVersion(self.version) >= LooseVersion("13"):
+            fftw_root = get_software_root('FFTW')
+            if fftw_root:
+                fftw_maj = get_software_version('FFTW').split('.')[0]
+                fftw_spec = 'FFTW%s' % fftw_maj
+            else:
+                raise EasyBuildError("Required FFTW dependency is missing")
+            qanda.update({
+                 '(not updated) Selection:': comp_answer,
+                 'Shared Memory Architecture? (y/N):': 'N',
+                 'Set MPI_REMOTE to  0 / 1:': '0',
+                 'You need to KNOW details about your installed  MPI and FFTW ) (y/n)': 'y',
+                 'Please specify whether you want to use FFTW3 (default) or FFTW2  (FFTW3 / FFTW2):' : fftw_spec,
+                 'Please specify the ROOT-path of your FFTW installation (like /opt/fftw3):' : fftw_root,
+                 'is this correct? enter Y (default) or n:' : 'Y',
+            })
+        else:
+            qanda.update({
                  'compiler) Selection:': comp_answer,
-                 'Your compiler:': '',
-                 'Hit Enter to continue': '',
                  'Shared Memory Architecture? (y/n):': 'n',
-                 'Remote shell (default is ssh) =': '',
-                 'and you need to know details about your installed  mpi ..) (y/n)': 'y',
-                 'Recommended setting for parallel f90 compiler: mpiifort ' \
-                        'Current selection: Your compiler:': os.getenv('MPIF90'),
-                 'Q to quit Selection:': 'Q',
-                 'A Compile all programs (suggested) Q Quit Selection:': 'Q',
-                 ' Please enter the full path of the perl program: ': '',
-                 'continue or stop (c/s)': 'c',
-                 '(like taskset -c). Enter N / your_specific_command:': 'N',
                  'If you are using mpi2 set MPI_REMOTE to 0  Set MPI_REMOTE to 0 / 1:': '0',
                  'Do you have MPI and Scalapack installed and intend to run ' \
                     'finegrained parallel? (This is usefull only for BIG cases ' \
                     '(50 atoms and more / unit cell) and you need to know details ' \
                     'about your installed  mpi and fftw ) (y/n)': 'y',
-                }
+            })
 
         no_qa = [
-                 'You have the following mkl libraries in %s :' % os.getenv('MKLROOT'),
-                 "%s[ \t]*.*"%os.getenv('MPIF90'),
-                 "%s[ \t]*.*"%os.getenv('F90'),
-                 "%s[ \t]*.*"%os.getenv('CC'),
-                 ".*SRC_.*",
-                 "Please enter the full path of the perl program:",
-                ]
+            'You have the following mkl libraries in %s :' % os.getenv('MKLROOT'),
+            "%s[ \t]*.*" % os.getenv('MPIF90'),
+            "%s[ \t]*.*" % os.getenv('F90'),
+            "%s[ \t]*.*" % os.getenv('CC'),
+            ".*SRC_.*",
+            "Please enter the full path of the perl program:",
+        ]
 
         std_qa = {
-                  r'S\s+Save and Quit[\s\n]+To change an item select option.[\s\n]+Selection:': 'S',
-                 }
+            r'S\s+Save and Quit[\s\n]+To change an item select option.[\s\n]+Selection:': 'S',
+            'Recommended setting for parallel f90 compiler: .* Current selection: Your compiler:': os.getenv('MPIF90'),
+        }
 
         run_cmd_qa(cmd, qanda, no_qa=no_qa, std_qa=std_qa, log_all=True, simple=True)
 
         # post-configure patches
-        fn = os.path.join(self.cfg['start_dir'], 'parallel_options')
-        remote = self.cfg['remote']
-        try:
-            for line in fileinput.input(fn, inplace=1, backup='.orig.eb'):
-                if self.cfg['wien_mpirun']:
-                    line = re.sub("(setenv WIEN_MPIRUN\s*).*", r'\1 "%s"' % self.cfg['wien_mpirun'], line)
-                sys.stdout.write(line)
+        parallel_options = {}
+        parallel_options_fp = os.path.join(self.cfg['start_dir'], 'parallel_options')
 
-            if remote:
-                f = open(fn, "a")
+        if self.cfg['wien_mpirun']:
+            parallel_options.update({'WIEN_MPIRUN': self.cfg['wien_mpirun']})
 
-                if remote == 'pbsssh':
-                    extra = "set remote = pbsssh\n"
-                    extra += "setenv PBSSSHENV 'LD_LIBRARY_PATH PATH'\n"
-                else:
-                    self.log.error("Don't know how to patch %s for remote %s" % (fn, remote))
+        if self.cfg['taskset'] is None:
+            self.cfg['taskset'] = 'no'
+        parallel_options.update({'TASKSET': self.cfg['taskset']})
 
-                f.write(extra)
-                f.close()
+        for opt in ['use_remote', 'mpi_remote', 'wien_granularity']:
+            parallel_options.update({opt.upper(): int(self.cfg[opt])})
 
-            self.log.debug("Patched file %s: %s" % (fn, open(fn, 'r').read()))
+        write_file(parallel_options_fp, '\n'.join(['setenv %s "%s"' % tup for tup in parallel_options.items()]))
 
-        except IOError, err:
-            self.log.error("Failed to patch %s: %s" % (fn, err))
+        if self.cfg['remote']:
+            if self.cfg['remote'] == 'pbsssh':
+                extratxt = '\n'.join([
+                    '',
+                    "set remote = pbsssh",
+                    "setenv PBSSSHENV 'LD_LIBRARY_PATH PATH'",
+                    '',
+                ])
+                write_file(parallel_options_fp, extratxt, append=True)
+            else:
+                raise EasyBuildError("Don't know how to handle remote %s", self.cfg['remote'])
 
+        self.log.debug("Patched file %s: %s", parallel_options_fp, read_file(parallel_options_fp))
 
     def build_step(self):
         """Build WIEN2k by running siteconfig_lapw script again."""
@@ -265,31 +290,35 @@ class EB_WIEN2k(EasyBlock):
 
             re_success = re.compile("LAPW1\s+END")
             if not re_success.search(out):
-                self.log.error("Test '%s' in %s failed (pattern '%s' not found)?" % (cmd, os.getcwd(),
-                                                                                     re_success.pattern))
+                raise EasyBuildError("Test '%s' in %s failed (pattern '%s' not found)?",
+                                     cmd, os.getcwd(), re_success.pattern)
             else:
                 self.log.info("Test '%s' seems to have run successfully: %s" % (cmd, out))
 
         if self.cfg['runtest']:
             if not self.cfg['testdata']:
-                self.log.error("List of URLs for testdata not provided.")
-
-            path = os.getenv('PATH')
-            env.setvar('PATH', "%s:%s" % (self.installdir, path))
+                raise EasyBuildError("List of URLs for testdata not provided.")
 
+            # prepend $PATH with install directory, define $SCRATCH which is used by the tests
+            env.setvar('PATH', "%s:%s" % (self.installdir, os.environ['PATH']))
             try:
                 cwd = os.getcwd()
 
                 # create temporary directory
                 tmpdir = tempfile.mkdtemp()
                 os.chdir(tmpdir)
+                self.log.info("Running tests in %s" % tmpdir)
+
+                scratch = os.path.join(tmpdir, 'scratch')
+                mkdir(scratch)
+                env.setvar('SCRATCH', scratch)
 
                 # download data
                 testdata_paths = {}
                 for testdata in self.cfg['testdata']:
                     td_path = self.obtain_file(testdata)
                     if not td_path:
-                        self.log.error("Downloading file from %s failed?" % testdata)
+                        raise EasyBuildError("Downloading file from %s failed?", testdata)
                     testdata_paths.update({os.path.basename(testdata): td_path})
 
                 self.log.debug('testdata_paths: %s' % testdata_paths)
@@ -314,21 +343,19 @@ class EB_WIEN2k(EasyBlock):
                 rmtree2(tmpdir)
 
             except OSError, err:
-                self.log.error("Failed to run WIEN2k benchmark tests: %s" % err)
-
-            # reset original path
-            env.setvar('PATH', path)
+                raise EasyBuildError("Failed to run WIEN2k benchmark tests: %s", err)
 
             self.log.debug("Current dir: %s" % os.getcwd())
 
     def test_cases_step(self):
         """Run test cases, if specified."""
+
         for test in self.cfg['tests']:
 
             # check expected format
             if not len(test) == 4:
-                self.log.error("WIEN2k test case not specified in expected format: " \
-                               "(testcase_name, init_lapw_args, run_lapw_args, [scf_regexp_pattern])")
+                raise EasyBuildError("WIEN2k test case not specified in expected format: "
+                                     "(testcase_name, init_lapw_args, run_lapw_args, [scf_regexp_pattern])")
             test_name = test[0]
             init_args = test[1]
             run_args = test[2]
@@ -338,10 +365,15 @@ class EB_WIEN2k(EasyBlock):
                 cwd = os.getcwd()
                 # WIEN2k enforces that working dir has same name as test case
                 tmpdir = os.path.join(tempfile.mkdtemp(), test_name)
-                os.mkdir(tmpdir)
+
+                scratch = os.path.join(tmpdir, 'scratch')
+                mkdir(scratch, parents=True)
+                env.setvar('SCRATCH', scratch)
+
                 os.chdir(tmpdir)
+                self.log.info("Running test case %s in %s" % (test_name, tmpdir))
             except OSError, err:
-                self.log.error("Failed to create temporary directory for test %s: %s" % (test_name, err))
+                raise EasyBuildError("Failed to create temporary directory for test %s: %s", test_name, err)
 
             # try and find struct file for test
             test_fp = self.obtain_file("%s.struct" % test_name)
@@ -349,7 +381,7 @@ class EB_WIEN2k(EasyBlock):
             try:
                 shutil.copy2(test_fp, tmpdir)
             except OSError, err:
-                self.log.error("Failed to copy %s: %s" % (test_fp, err))
+                raise EasyBuildError("Failed to copy %s: %s", test_fp, err)
 
             # run test
             cmd = "init_lapw %s" % init_args
@@ -361,16 +393,11 @@ class EB_WIEN2k(EasyBlock):
             # check output
             scf_fn = "%s.scf" % test_name
             self.log.debug("Checking output of test %s in %s" % (str(test), scf_fn))
-            try:
-                f = open(scf_fn, "r")
-                scftxt = f.read()
-                f.close()
-            except IOError, err:
-                self.log.error("Failed to read file %s: %s" % (scf_fn, err))
+            scftxt = read_file(scf_fn)
             for regexp_pat in scf_regexp_patterns:
                 regexp = re.compile(regexp_pat, re.M)
                 if not regexp.search(scftxt):
-                    self.log.error("Failed to find pattern %s in %s" % (regexp.pattern, scf_fn))
+                    raise EasyBuildError("Failed to find pattern %s in %s", regexp.pattern, scf_fn)
                 else:
                     self.log.debug("Found pattern %s in %s" % (regexp.pattern, scf_fn))
 
@@ -379,7 +406,7 @@ class EB_WIEN2k(EasyBlock):
                 os.chdir(cwd)
                 rmtree2(tmpdir)
             except OSError, err:
-                self.log.error("Failed to clean up temporary test dir: %s" % err)
+                raise EasyBuildError("Failed to clean up temporary test dir: %s", err)
 
     def install_step(self):
         """Fix broken symlinks after build/installation."""
@@ -392,15 +419,15 @@ class EB_WIEN2k(EasyBlock):
         """Custom sanity check for WIEN2k."""
 
         lapwfiles = []
-        for suffix in ["0","0_mpi","1","1_mpi","1c","1c_mpi","2","2_mpi","2c","2c_mpi",
-                       "3","3c","5","5c","7","7c","dm","dmc","so"]:
+        for suffix in ['0', '0_mpi', '1', '1_mpi', '1c', '1c_mpi', '2', '2_mpi', '2c' ,'2c_mpi',
+                       '3', '3c', '5', '5c', '7', '7c', 'dm', 'dmc', 'so']:
             p = os.path.join(self.installdir, "lapw%s" % suffix)
             lapwfiles.append(p)
 
         custom_paths = {
-                        'files': lapwfiles,
-                        'dirs': []
-                       }
+            'files': lapwfiles,
+            'dirs': [],
+        }
 
         super(EB_WIEN2k, self).sanity_check_step(custom_paths=custom_paths)
 
@@ -409,7 +436,7 @@ class EB_WIEN2k(EasyBlock):
 
         txt = super(EB_WIEN2k, self).make_module_extra()
 
-        txt += self.module_generator.set_environment("WIENROOT", "$root")
+        txt += self.module_generator.set_environment("WIENROOT", self.installdir)
         txt += self.module_generator.prepend_paths("PATH", [""])
 
         return txt
