@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2013 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -34,12 +34,18 @@ import shutil
 import sys
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.modules import get_software_root, get_software_version
 
 
 class EB_XCrySDen(ConfigureMake):
     """Support for building/installing XCrySDen."""
 
+    def __init__(self, *args, **kwargs):
+        """Initialisation of custom class variables for XCrySDen"""
+        super(EB_XCrySDen, self).__init__(*args, **kwargs)
+        self.tclroot = self.tclver = self.tkroot = self.tkver = 'UNKNOWN'
+
     def configure_step(self):
         """
         Check required dependencies, configure XCrySDen build by patching Make.sys file
@@ -50,7 +56,7 @@ class EB_XCrySDen(ConfigureMake):
         deps = ["Mesa", "Tcl", "Tk"]
         for dep in deps:
             if not get_software_root(dep):
-                self.log.error("Module for dependency %s not loaded." % dep)
+                raise EasyBuildError("Module for dependency %s not loaded.", dep)
 
         # copy template Make.sys to apply_patch
         makesys_tpl_file = os.path.join("system", "Make.sys-shared")
@@ -58,7 +64,7 @@ class EB_XCrySDen(ConfigureMake):
         try:
             shutil.copy2(makesys_tpl_file, makesys_file)
         except OSError, err:
-            self.log.error("Failed to copy %s: %s" % (makesys_tpl_file, err))
+            raise EasyBuildError("Failed to copy %s: %s", makesys_tpl_file, err)
 
         self.tclroot = get_software_root("Tcl")
         self.tclver = '.'.join(get_software_version("Tcl").split('.')[0:2])
